#include <tree_sitter/parser.h>

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#define LANGUAGE_VERSION 13
#define STATE_COUNT 230
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 123
#define ALIAS_COUNT 0
#define TOKEN_COUNT 81
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 0
#define MAX_ALIAS_SEQUENCE_LENGTH 10
#define PRODUCTION_ID_COUNT 1

enum {
  sym_identifier = 1,
  anon_sym_include = 2,
  anon_sym_cpp_include = 3,
  anon_sym_namespace = 4,
  anon_sym_STAR = 5,
  anon_sym_c_glib = 6,
  anon_sym_cpp = 7,
  anon_sym_d = 8,
  anon_sym_dart = 9,
  anon_sym_delphi = 10,
  anon_sym_erl = 11,
  anon_sym_go = 12,
  anon_sym_haxe = 13,
  anon_sym_java = 14,
  anon_sym_javame = 15,
  anon_sym_js = 16,
  anon_sym_kotlin = 17,
  anon_sym_lua = 18,
  anon_sym_netstd = 19,
  anon_sym_nodejs = 20,
  anon_sym_nodets = 21,
  anon_sym_ocaml = 22,
  anon_sym_perl = 23,
  anon_sym_php = 24,
  anon_sym_py = 25,
  anon_sym_py_DOTtwisted = 26,
  anon_sym_rb = 27,
  anon_sym_rs = 28,
  anon_sym_st = 29,
  anon_sym_swift = 30,
  anon_sym_ts = 31,
  anon_sym_xsd = 32,
  anon_sym_const = 33,
  anon_sym_EQ = 34,
  anon_sym_typedef = 35,
  anon_sym_enum = 36,
  anon_sym_LBRACE = 37,
  anon_sym_RBRACE = 38,
  anon_sym_senum = 39,
  anon_sym_struct = 40,
  anon_sym_xsd_all = 41,
  anon_sym_union = 42,
  anon_sym_exception = 43,
  anon_sym_service = 44,
  anon_sym_extends = 45,
  anon_sym_xsd_optional = 46,
  anon_sym_xsd_nillable = 47,
  anon_sym_COLON = 48,
  anon_sym_required = 49,
  anon_sym_optional = 50,
  anon_sym_xsd_attrs = 51,
  anon_sym_oneway = 52,
  anon_sym_LPAREN = 53,
  anon_sym_RPAREN = 54,
  anon_sym_void = 55,
  anon_sym_throws = 56,
  anon_sym_bool = 57,
  anon_sym_byte = 58,
  anon_sym_i8 = 59,
  anon_sym_i16 = 60,
  anon_sym_i32 = 61,
  anon_sym_i64 = 62,
  anon_sym_double = 63,
  anon_sym_string = 64,
  anon_sym_binary = 65,
  anon_sym_slist = 66,
  anon_sym_map = 67,
  anon_sym_LT = 68,
  anon_sym_COMMA = 69,
  anon_sym_GT = 70,
  anon_sym_set = 71,
  anon_sym_list = 72,
  anon_sym_cpp_type = 73,
  sym_int_constant = 74,
  sym_double_constant = 75,
  anon_sym_LBRACK = 76,
  anon_sym_RBRACK = 77,
  sym_literal = 78,
  anon_sym_SEMI = 79,
  sym_comment = 80,
  sym_document = 81,
  sym_header = 82,
  sym_include = 83,
  sym_cpp_include = 84,
  sym_namespace = 85,
  sym_namespace_scope = 86,
  sym_definition = 87,
  sym_const = 88,
  sym_typedef = 89,
  sym_enum = 90,
  sym_senum = 91,
  sym_struct = 92,
  sym_union = 93,
  sym_exception = 94,
  sym_service = 95,
  sym_field = 96,
  sym_field_id = 97,
  sym_field_req = 98,
  sym_xsd_attrs = 99,
  sym_function = 100,
  sym_function_type = 101,
  sym_throws = 102,
  sym_field_type = 103,
  sym_definition_type = 104,
  sym_base_type = 105,
  sym_container_type = 106,
  sym_map_type = 107,
  sym_set_type = 108,
  sym_list_type = 109,
  sym_cpp_type = 110,
  sym_const_value = 111,
  sym_const_list = 112,
  sym_const_map = 113,
  sym_list_separator = 114,
  aux_sym_document_repeat1 = 115,
  aux_sym_document_repeat2 = 116,
  aux_sym_enum_repeat1 = 117,
  aux_sym_senum_repeat1 = 118,
  aux_sym_struct_repeat1 = 119,
  aux_sym_service_repeat1 = 120,
  aux_sym_const_list_repeat1 = 121,
  aux_sym_const_map_repeat1 = 122,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_identifier] = "identifier",
  [anon_sym_include] = "include",
  [anon_sym_cpp_include] = "cpp_include",
  [anon_sym_namespace] = "namespace",
  [anon_sym_STAR] = "*",
  [anon_sym_c_glib] = "c_glib",
  [anon_sym_cpp] = "cpp",
  [anon_sym_d] = "d",
  [anon_sym_dart] = "dart",
  [anon_sym_delphi] = "delphi",
  [anon_sym_erl] = "erl",
  [anon_sym_go] = "go",
  [anon_sym_haxe] = "haxe",
  [anon_sym_java] = "java",
  [anon_sym_javame] = "javame",
  [anon_sym_js] = "js",
  [anon_sym_kotlin] = "kotlin",
  [anon_sym_lua] = "lua",
  [anon_sym_netstd] = "netstd",
  [anon_sym_nodejs] = "nodejs",
  [anon_sym_nodets] = "nodets",
  [anon_sym_ocaml] = "ocaml",
  [anon_sym_perl] = "perl",
  [anon_sym_php] = "php",
  [anon_sym_py] = "py",
  [anon_sym_py_DOTtwisted] = "py.twisted",
  [anon_sym_rb] = "rb",
  [anon_sym_rs] = "rs",
  [anon_sym_st] = "st",
  [anon_sym_swift] = "swift",
  [anon_sym_ts] = "ts",
  [anon_sym_xsd] = "xsd",
  [anon_sym_const] = "const",
  [anon_sym_EQ] = "=",
  [anon_sym_typedef] = "typedef",
  [anon_sym_enum] = "enum",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_senum] = "senum",
  [anon_sym_struct] = "struct",
  [anon_sym_xsd_all] = "xsd_all",
  [anon_sym_union] = "union",
  [anon_sym_exception] = "exception",
  [anon_sym_service] = "service",
  [anon_sym_extends] = "extends",
  [anon_sym_xsd_optional] = "xsd_optional",
  [anon_sym_xsd_nillable] = "xsd_nillable",
  [anon_sym_COLON] = ":",
  [anon_sym_required] = "required",
  [anon_sym_optional] = "optional",
  [anon_sym_xsd_attrs] = "xsd_attrs",
  [anon_sym_oneway] = "oneway",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_void] = "void",
  [anon_sym_throws] = "throws",
  [anon_sym_bool] = "bool",
  [anon_sym_byte] = "byte",
  [anon_sym_i8] = "i8",
  [anon_sym_i16] = "i16",
  [anon_sym_i32] = "i32",
  [anon_sym_i64] = "i64",
  [anon_sym_double] = "double",
  [anon_sym_string] = "string",
  [anon_sym_binary] = "binary",
  [anon_sym_slist] = "slist",
  [anon_sym_map] = "map",
  [anon_sym_LT] = "<",
  [anon_sym_COMMA] = ",",
  [anon_sym_GT] = ">",
  [anon_sym_set] = "set",
  [anon_sym_list] = "list",
  [anon_sym_cpp_type] = "cpp_type",
  [sym_int_constant] = "int_constant",
  [sym_double_constant] = "double_constant",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [sym_literal] = "literal",
  [anon_sym_SEMI] = ";",
  [sym_comment] = "comment",
  [sym_document] = "document",
  [sym_header] = "header",
  [sym_include] = "include",
  [sym_cpp_include] = "cpp_include",
  [sym_namespace] = "namespace",
  [sym_namespace_scope] = "namespace_scope",
  [sym_definition] = "definition",
  [sym_const] = "const",
  [sym_typedef] = "typedef",
  [sym_enum] = "enum",
  [sym_senum] = "senum",
  [sym_struct] = "struct",
  [sym_union] = "union",
  [sym_exception] = "exception",
  [sym_service] = "service",
  [sym_field] = "field",
  [sym_field_id] = "field_id",
  [sym_field_req] = "field_req",
  [sym_xsd_attrs] = "xsd_attrs",
  [sym_function] = "function",
  [sym_function_type] = "function_type",
  [sym_throws] = "throws",
  [sym_field_type] = "field_type",
  [sym_definition_type] = "definition_type",
  [sym_base_type] = "base_type",
  [sym_container_type] = "container_type",
  [sym_map_type] = "map_type",
  [sym_set_type] = "set_type",
  [sym_list_type] = "list_type",
  [sym_cpp_type] = "cpp_type",
  [sym_const_value] = "const_value",
  [sym_const_list] = "const_list",
  [sym_const_map] = "const_map",
  [sym_list_separator] = "list_separator",
  [aux_sym_document_repeat1] = "document_repeat1",
  [aux_sym_document_repeat2] = "document_repeat2",
  [aux_sym_enum_repeat1] = "enum_repeat1",
  [aux_sym_senum_repeat1] = "senum_repeat1",
  [aux_sym_struct_repeat1] = "struct_repeat1",
  [aux_sym_service_repeat1] = "service_repeat1",
  [aux_sym_const_list_repeat1] = "const_list_repeat1",
  [aux_sym_const_map_repeat1] = "const_map_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_identifier] = sym_identifier,
  [anon_sym_include] = anon_sym_include,
  [anon_sym_cpp_include] = anon_sym_cpp_include,
  [anon_sym_namespace] = anon_sym_namespace,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_c_glib] = anon_sym_c_glib,
  [anon_sym_cpp] = anon_sym_cpp,
  [anon_sym_d] = anon_sym_d,
  [anon_sym_dart] = anon_sym_dart,
  [anon_sym_delphi] = anon_sym_delphi,
  [anon_sym_erl] = anon_sym_erl,
  [anon_sym_go] = anon_sym_go,
  [anon_sym_haxe] = anon_sym_haxe,
  [anon_sym_java] = anon_sym_java,
  [anon_sym_javame] = anon_sym_javame,
  [anon_sym_js] = anon_sym_js,
  [anon_sym_kotlin] = anon_sym_kotlin,
  [anon_sym_lua] = anon_sym_lua,
  [anon_sym_netstd] = anon_sym_netstd,
  [anon_sym_nodejs] = anon_sym_nodejs,
  [anon_sym_nodets] = anon_sym_nodets,
  [anon_sym_ocaml] = anon_sym_ocaml,
  [anon_sym_perl] = anon_sym_perl,
  [anon_sym_php] = anon_sym_php,
  [anon_sym_py] = anon_sym_py,
  [anon_sym_py_DOTtwisted] = anon_sym_py_DOTtwisted,
  [anon_sym_rb] = anon_sym_rb,
  [anon_sym_rs] = anon_sym_rs,
  [anon_sym_st] = anon_sym_st,
  [anon_sym_swift] = anon_sym_swift,
  [anon_sym_ts] = anon_sym_ts,
  [anon_sym_xsd] = anon_sym_xsd,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_typedef] = anon_sym_typedef,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_senum] = anon_sym_senum,
  [anon_sym_struct] = anon_sym_struct,
  [anon_sym_xsd_all] = anon_sym_xsd_all,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_exception] = anon_sym_exception,
  [anon_sym_service] = anon_sym_service,
  [anon_sym_extends] = anon_sym_extends,
  [anon_sym_xsd_optional] = anon_sym_xsd_optional,
  [anon_sym_xsd_nillable] = anon_sym_xsd_nillable,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_required] = anon_sym_required,
  [anon_sym_optional] = anon_sym_optional,
  [anon_sym_xsd_attrs] = anon_sym_xsd_attrs,
  [anon_sym_oneway] = anon_sym_oneway,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_void] = anon_sym_void,
  [anon_sym_throws] = anon_sym_throws,
  [anon_sym_bool] = anon_sym_bool,
  [anon_sym_byte] = anon_sym_byte,
  [anon_sym_i8] = anon_sym_i8,
  [anon_sym_i16] = anon_sym_i16,
  [anon_sym_i32] = anon_sym_i32,
  [anon_sym_i64] = anon_sym_i64,
  [anon_sym_double] = anon_sym_double,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_binary] = anon_sym_binary,
  [anon_sym_slist] = anon_sym_slist,
  [anon_sym_map] = anon_sym_map,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_set] = anon_sym_set,
  [anon_sym_list] = anon_sym_list,
  [anon_sym_cpp_type] = anon_sym_cpp_type,
  [sym_int_constant] = sym_int_constant,
  [sym_double_constant] = sym_double_constant,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [sym_literal] = sym_literal,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [sym_comment] = sym_comment,
  [sym_document] = sym_document,
  [sym_header] = sym_header,
  [sym_include] = sym_include,
  [sym_cpp_include] = sym_cpp_include,
  [sym_namespace] = sym_namespace,
  [sym_namespace_scope] = sym_namespace_scope,
  [sym_definition] = sym_definition,
  [sym_const] = sym_const,
  [sym_typedef] = sym_typedef,
  [sym_enum] = sym_enum,
  [sym_senum] = sym_senum,
  [sym_struct] = sym_struct,
  [sym_union] = sym_union,
  [sym_exception] = sym_exception,
  [sym_service] = sym_service,
  [sym_field] = sym_field,
  [sym_field_id] = sym_field_id,
  [sym_field_req] = sym_field_req,
  [sym_xsd_attrs] = sym_xsd_attrs,
  [sym_function] = sym_function,
  [sym_function_type] = sym_function_type,
  [sym_throws] = sym_throws,
  [sym_field_type] = sym_field_type,
  [sym_definition_type] = sym_definition_type,
  [sym_base_type] = sym_base_type,
  [sym_container_type] = sym_container_type,
  [sym_map_type] = sym_map_type,
  [sym_set_type] = sym_set_type,
  [sym_list_type] = sym_list_type,
  [sym_cpp_type] = sym_cpp_type,
  [sym_const_value] = sym_const_value,
  [sym_const_list] = sym_const_list,
  [sym_const_map] = sym_const_map,
  [sym_list_separator] = sym_list_separator,
  [aux_sym_document_repeat1] = aux_sym_document_repeat1,
  [aux_sym_document_repeat2] = aux_sym_document_repeat2,
  [aux_sym_enum_repeat1] = aux_sym_enum_repeat1,
  [aux_sym_senum_repeat1] = aux_sym_senum_repeat1,
  [aux_sym_struct_repeat1] = aux_sym_struct_repeat1,
  [aux_sym_service_repeat1] = aux_sym_service_repeat1,
  [aux_sym_const_list_repeat1] = aux_sym_const_list_repeat1,
  [aux_sym_const_map_repeat1] = aux_sym_const_map_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_include] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cpp_include] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_namespace] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_c_glib] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cpp] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_d] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_dart] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delphi] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_erl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_go] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_haxe] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_java] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_javame] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_js] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_kotlin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_lua] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_netstd] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nodejs] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_nodets] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ocaml] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_perl] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_php] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_py] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_py_DOTtwisted] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rb] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_rs] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_st] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_swift] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ts] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xsd] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_typedef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_senum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_struct] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xsd_all] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_exception] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_service] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_extends] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xsd_optional] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xsd_nillable] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_required] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_optional] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_xsd_attrs] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_oneway] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_void] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_throws] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bool] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_byte] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_i8] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_i16] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_i32] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_i64] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_double] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_binary] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_slist] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_map] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_list] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_cpp_type] = {
    .visible = true,
    .named = false,
  },
  [sym_int_constant] = {
    .visible = true,
    .named = true,
  },
  [sym_double_constant] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [sym_literal] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_document] = {
    .visible = true,
    .named = true,
  },
  [sym_header] = {
    .visible = true,
    .named = true,
  },
  [sym_include] = {
    .visible = true,
    .named = true,
  },
  [sym_cpp_include] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace] = {
    .visible = true,
    .named = true,
  },
  [sym_namespace_scope] = {
    .visible = true,
    .named = true,
  },
  [sym_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_const] = {
    .visible = true,
    .named = true,
  },
  [sym_typedef] = {
    .visible = true,
    .named = true,
  },
  [sym_enum] = {
    .visible = true,
    .named = true,
  },
  [sym_senum] = {
    .visible = true,
    .named = true,
  },
  [sym_struct] = {
    .visible = true,
    .named = true,
  },
  [sym_union] = {
    .visible = true,
    .named = true,
  },
  [sym_exception] = {
    .visible = true,
    .named = true,
  },
  [sym_service] = {
    .visible = true,
    .named = true,
  },
  [sym_field] = {
    .visible = true,
    .named = true,
  },
  [sym_field_id] = {
    .visible = true,
    .named = true,
  },
  [sym_field_req] = {
    .visible = true,
    .named = true,
  },
  [sym_xsd_attrs] = {
    .visible = true,
    .named = true,
  },
  [sym_function] = {
    .visible = true,
    .named = true,
  },
  [sym_function_type] = {
    .visible = true,
    .named = true,
  },
  [sym_throws] = {
    .visible = true,
    .named = true,
  },
  [sym_field_type] = {
    .visible = true,
    .named = true,
  },
  [sym_definition_type] = {
    .visible = true,
    .named = true,
  },
  [sym_base_type] = {
    .visible = true,
    .named = true,
  },
  [sym_container_type] = {
    .visible = true,
    .named = true,
  },
  [sym_map_type] = {
    .visible = true,
    .named = true,
  },
  [sym_set_type] = {
    .visible = true,
    .named = true,
  },
  [sym_list_type] = {
    .visible = true,
    .named = true,
  },
  [sym_cpp_type] = {
    .visible = true,
    .named = true,
  },
  [sym_const_value] = {
    .visible = true,
    .named = true,
  },
  [sym_const_list] = {
    .visible = true,
    .named = true,
  },
  [sym_const_map] = {
    .visible = true,
    .named = true,
  },
  [sym_list_separator] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_document_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_document_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_senum_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_struct_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_service_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_const_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_const_map_repeat1] = {
    .visible = false,
    .named = false,
  },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(17);
      if (lookahead == '"') ADVANCE(4);
      if (lookahead == '#') ADVANCE(38);
      if (lookahead == '\'') ADVANCE(5);
      if (lookahead == '(') ADVANCE(23);
      if (lookahead == ')') ADVANCE(24);
      if (lookahead == '*') ADVANCE(18);
      if (lookahead == ',') ADVANCE(26);
      if (lookahead == '.') ADVANCE(11);
      if (lookahead == '/') ADVANCE(6);
      if (lookahead == ':') ADVANCE(22);
      if (lookahead == ';') ADVANCE(36);
      if (lookahead == '<') ADVANCE(25);
      if (lookahead == '=') ADVANCE(19);
      if (lookahead == '>') ADVANCE(27);
      if (lookahead == '[') ADVANCE(32);
      if (lookahead == '\\') SKIP(16)
      if (lookahead == ']') ADVANCE(33);
      if (lookahead == '{') ADVANCE(20);
      if (lookahead == '}') ADVANCE(21);
      if (('+' <= lookahead && lookahead <= '-')) ADVANCE(9);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(0)
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(28);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(3)
      END_STATE();
    case 2:
      if (lookahead == '\n') SKIP(3)
      if (lookahead == '\r') SKIP(1)
      END_STATE();
    case 3:
      if (lookahead == '"') ADVANCE(4);
      if (lookahead == '#') ADVANCE(38);
      if (lookahead == '\'') ADVANCE(5);
      if (lookahead == ')') ADVANCE(24);
      if (lookahead == ',') ADVANCE(26);
      if (lookahead == '/') ADVANCE(6);
      if (lookahead == ';') ADVANCE(36);
      if (lookahead == '=') ADVANCE(19);
      if (lookahead == '\\') SKIP(2)
      if (lookahead == '}') ADVANCE(21);
      if (('+' <= lookahead && lookahead <= '-')) ADVANCE(13);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(3)
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(29);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 4:
      if (lookahead == '"') ADVANCE(34);
      if (lookahead != 0) ADVANCE(4);
      END_STATE();
    case 5:
      if (lookahead == '\'') ADVANCE(34);
      if (lookahead != 0) ADVANCE(5);
      END_STATE();
    case 6:
      if (lookahead == '*') ADVANCE(8);
      if (lookahead == '/') ADVANCE(38);
      END_STATE();
    case 7:
      if (lookahead == '*') ADVANCE(7);
      if (lookahead == '/') ADVANCE(37);
      if (lookahead != 0) ADVANCE(8);
      END_STATE();
    case 8:
      if (lookahead == '*') ADVANCE(7);
      if (lookahead != 0) ADVANCE(8);
      END_STATE();
    case 9:
      if (lookahead == '.') ADVANCE(11);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(28);
      END_STATE();
    case 10:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(12);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(31);
      END_STATE();
    case 11:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(30);
      END_STATE();
    case 12:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(31);
      END_STATE();
    case 13:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(29);
      END_STATE();
    case 14:
      if (lookahead != 0 &&
          lookahead != '\r') ADVANCE(38);
      if (lookahead == '\r') ADVANCE(39);
      END_STATE();
    case 15:
      if (eof) ADVANCE(17);
      if (lookahead == '\n') SKIP(0)
      END_STATE();
    case 16:
      if (eof) ADVANCE(17);
      if (lookahead == '\n') SKIP(0)
      if (lookahead == '\r') SKIP(15)
      END_STATE();
    case 17:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 18:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 19:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 20:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 21:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 22:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 23:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 24:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 25:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 26:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 27:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 28:
      ACCEPT_TOKEN(sym_int_constant);
      if (lookahead == '.') ADVANCE(11);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(10);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(28);
      END_STATE();
    case 29:
      ACCEPT_TOKEN(sym_int_constant);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(29);
      END_STATE();
    case 30:
      ACCEPT_TOKEN(sym_double_constant);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(10);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(30);
      END_STATE();
    case 31:
      ACCEPT_TOKEN(sym_double_constant);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(31);
      END_STATE();
    case 32:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 33:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 34:
      ACCEPT_TOKEN(sym_literal);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '.' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 36:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 37:
      ACCEPT_TOKEN(sym_comment);
      END_STATE();
    case 38:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead == '\\') ADVANCE(14);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(38);
      END_STATE();
    case 39:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\\') ADVANCE(38);
      if (lookahead == '\\') ADVANCE(14);
      END_STATE();
    default:
      return false;
  }
}

static bool ts_lex_keywords(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (lookahead == '\\') SKIP(1)
      if (lookahead == 'b') ADVANCE(2);
      if (lookahead == 'c') ADVANCE(3);
      if (lookahead == 'd') ADVANCE(4);
      if (lookahead == 'e') ADVANCE(5);
      if (lookahead == 'g') ADVANCE(6);
      if (lookahead == 'h') ADVANCE(7);
      if (lookahead == 'i') ADVANCE(8);
      if (lookahead == 'j') ADVANCE(9);
      if (lookahead == 'k') ADVANCE(10);
      if (lookahead == 'l') ADVANCE(11);
      if (lookahead == 'm') ADVANCE(12);
      if (lookahead == 'n') ADVANCE(13);
      if (lookahead == 'o') ADVANCE(14);
      if (lookahead == 'p') ADVANCE(15);
      if (lookahead == 'r') ADVANCE(16);
      if (lookahead == 's') ADVANCE(17);
      if (lookahead == 't') ADVANCE(18);
      if (lookahead == 'u') ADVANCE(19);
      if (lookahead == 'v') ADVANCE(20);
      if (lookahead == 'x') ADVANCE(21);
      if (lookahead == '\t' ||
          lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == ' ') SKIP(0)
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(0)
      if (lookahead == '\r') SKIP(22)
      END_STATE();
    case 2:
      if (lookahead == 'i') ADVANCE(23);
      if (lookahead == 'o') ADVANCE(24);
      if (lookahead == 'y') ADVANCE(25);
      END_STATE();
    case 3:
      if (lookahead == '_') ADVANCE(26);
      if (lookahead == 'o') ADVANCE(27);
      if (lookahead == 'p') ADVANCE(28);
      END_STATE();
    case 4:
      ACCEPT_TOKEN(anon_sym_d);
      if (lookahead == 'a') ADVANCE(29);
      if (lookahead == 'e') ADVANCE(30);
      if (lookahead == 'o') ADVANCE(31);
      END_STATE();
    case 5:
      if (lookahead == 'n') ADVANCE(32);
      if (lookahead == 'r') ADVANCE(33);
      if (lookahead == 'x') ADVANCE(34);
      END_STATE();
    case 6:
      if (lookahead == 'o') ADVANCE(35);
      END_STATE();
    case 7:
      if (lookahead == 'a') ADVANCE(36);
      END_STATE();
    case 8:
      if (lookahead == '1') ADVANCE(37);
      if (lookahead == '3') ADVANCE(38);
      if (lookahead == '6') ADVANCE(39);
      if (lookahead == '8') ADVANCE(40);
      if (lookahead == 'n') ADVANCE(41);
      END_STATE();
    case 9:
      if (lookahead == 'a') ADVANCE(42);
      if (lookahead == 's') ADVANCE(43);
      END_STATE();
    case 10:
      if (lookahead == 'o') ADVANCE(44);
      END_STATE();
    case 11:
      if (lookahead == 'i') ADVANCE(45);
      if (lookahead == 'u') ADVANCE(46);
      END_STATE();
    case 12:
      if (lookahead == 'a') ADVANCE(47);
      END_STATE();
    case 13:
      if (lookahead == 'a') ADVANCE(48);
      if (lookahead == 'e') ADVANCE(49);
      if (lookahead == 'o') ADVANCE(50);
      END_STATE();
    case 14:
      if (lookahead == 'c') ADVANCE(51);
      if (lookahead == 'n') ADVANCE(52);
      if (lookahead == 'p') ADVANCE(53);
      END_STATE();
    case 15:
      if (lookahead == 'e') ADVANCE(54);
      if (lookahead == 'h') ADVANCE(55);
      if (lookahead == 'y') ADVANCE(56);
      END_STATE();
    case 16:
      if (lookahead == 'b') ADVANCE(57);
      if (lookahead == 'e') ADVANCE(58);
      if (lookahead == 's') ADVANCE(59);
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(60);
      if (lookahead == 'l') ADVANCE(61);
      if (lookahead == 't') ADVANCE(62);
      if (lookahead == 'w') ADVANCE(63);
      END_STATE();
    case 18:
      if (lookahead == 'h') ADVANCE(64);
      if (lookahead == 's') ADVANCE(65);
      if (lookahead == 'y') ADVANCE(66);
      END_STATE();
    case 19:
      if (lookahead == 'n') ADVANCE(67);
      END_STATE();
    case 20:
      if (lookahead == 'o') ADVANCE(68);
      END_STATE();
    case 21:
      if (lookahead == 's') ADVANCE(69);
      END_STATE();
    case 22:
      if (lookahead == '\n') SKIP(0)
      END_STATE();
    case 23:
      if (lookahead == 'n') ADVANCE(70);
      END_STATE();
    case 24:
      if (lookahead == 'o') ADVANCE(71);
      END_STATE();
    case 25:
      if (lookahead == 't') ADVANCE(72);
      END_STATE();
    case 26:
      if (lookahead == 'g') ADVANCE(73);
      END_STATE();
    case 27:
      if (lookahead == 'n') ADVANCE(74);
      END_STATE();
    case 28:
      if (lookahead == 'p') ADVANCE(75);
      END_STATE();
    case 29:
      if (lookahead == 'r') ADVANCE(76);
      END_STATE();
    case 30:
      if (lookahead == 'l') ADVANCE(77);
      END_STATE();
    case 31:
      if (lookahead == 'u') ADVANCE(78);
      END_STATE();
    case 32:
      if (lookahead == 'u') ADVANCE(79);
      END_STATE();
    case 33:
      if (lookahead == 'l') ADVANCE(80);
      END_STATE();
    case 34:
      if (lookahead == 'c') ADVANCE(81);
      if (lookahead == 't') ADVANCE(82);
      END_STATE();
    case 35:
      ACCEPT_TOKEN(anon_sym_go);
      END_STATE();
    case 36:
      if (lookahead == 'x') ADVANCE(83);
      END_STATE();
    case 37:
      if (lookahead == '6') ADVANCE(84);
      END_STATE();
    case 38:
      if (lookahead == '2') ADVANCE(85);
      END_STATE();
    case 39:
      if (lookahead == '4') ADVANCE(86);
      END_STATE();
    case 40:
      ACCEPT_TOKEN(anon_sym_i8);
      END_STATE();
    case 41:
      if (lookahead == 'c') ADVANCE(87);
      END_STATE();
    case 42:
      if (lookahead == 'v') ADVANCE(88);
      END_STATE();
    case 43:
      ACCEPT_TOKEN(anon_sym_js);
      END_STATE();
    case 44:
      if (lookahead == 't') ADVANCE(89);
      END_STATE();
    case 45:
      if (lookahead == 's') ADVANCE(90);
      END_STATE();
    case 46:
      if (lookahead == 'a') ADVANCE(91);
      END_STATE();
    case 47:
      if (lookahead == 'p') ADVANCE(92);
      END_STATE();
    case 48:
      if (lookahead == 'm') ADVANCE(93);
      END_STATE();
    case 49:
      if (lookahead == 't') ADVANCE(94);
      END_STATE();
    case 50:
      if (lookahead == 'd') ADVANCE(95);
      END_STATE();
    case 51:
      if (lookahead == 'a') ADVANCE(96);
      END_STATE();
    case 52:
      if (lookahead == 'e') ADVANCE(97);
      END_STATE();
    case 53:
      if (lookahead == 't') ADVANCE(98);
      END_STATE();
    case 54:
      if (lookahead == 'r') ADVANCE(99);
      END_STATE();
    case 55:
      if (lookahead == 'p') ADVANCE(100);
      END_STATE();
    case 56:
      ACCEPT_TOKEN(anon_sym_py);
      if (lookahead == '.') ADVANCE(101);
      END_STATE();
    case 57:
      ACCEPT_TOKEN(anon_sym_rb);
      END_STATE();
    case 58:
      if (lookahead == 'q') ADVANCE(102);
      END_STATE();
    case 59:
      ACCEPT_TOKEN(anon_sym_rs);
      END_STATE();
    case 60:
      if (lookahead == 'n') ADVANCE(103);
      if (lookahead == 'r') ADVANCE(104);
      if (lookahead == 't') ADVANCE(105);
      END_STATE();
    case 61:
      if (lookahead == 'i') ADVANCE(106);
      END_STATE();
    case 62:
      ACCEPT_TOKEN(anon_sym_st);
      if (lookahead == 'r') ADVANCE(107);
      END_STATE();
    case 63:
      if (lookahead == 'i') ADVANCE(108);
      END_STATE();
    case 64:
      if (lookahead == 'r') ADVANCE(109);
      END_STATE();
    case 65:
      ACCEPT_TOKEN(anon_sym_ts);
      END_STATE();
    case 66:
      if (lookahead == 'p') ADVANCE(110);
      END_STATE();
    case 67:
      if (lookahead == 'i') ADVANCE(111);
      END_STATE();
    case 68:
      if (lookahead == 'i') ADVANCE(112);
      END_STATE();
    case 69:
      if (lookahead == 'd') ADVANCE(113);
      END_STATE();
    case 70:
      if (lookahead == 'a') ADVANCE(114);
      END_STATE();
    case 71:
      if (lookahead == 'l') ADVANCE(115);
      END_STATE();
    case 72:
      if (lookahead == 'e') ADVANCE(116);
      END_STATE();
    case 73:
      if (lookahead == 'l') ADVANCE(117);
      END_STATE();
    case 74:
      if (lookahead == 's') ADVANCE(118);
      END_STATE();
    case 75:
      ACCEPT_TOKEN(anon_sym_cpp);
      if (lookahead == '_') ADVANCE(119);
      END_STATE();
    case 76:
      if (lookahead == 't') ADVANCE(120);
      END_STATE();
    case 77:
      if (lookahead == 'p') ADVANCE(121);
      END_STATE();
    case 78:
      if (lookahead == 'b') ADVANCE(122);
      END_STATE();
    case 79:
      if (lookahead == 'm') ADVANCE(123);
      END_STATE();
    case 80:
      ACCEPT_TOKEN(anon_sym_erl);
      END_STATE();
    case 81:
      if (lookahead == 'e') ADVANCE(124);
      END_STATE();
    case 82:
      if (lookahead == 'e') ADVANCE(125);
      END_STATE();
    case 83:
      if (lookahead == 'e') ADVANCE(126);
      END_STATE();
    case 84:
      ACCEPT_TOKEN(anon_sym_i16);
      END_STATE();
    case 85:
      ACCEPT_TOKEN(anon_sym_i32);
      END_STATE();
    case 86:
      ACCEPT_TOKEN(anon_sym_i64);
      END_STATE();
    case 87:
      if (lookahead == 'l') ADVANCE(127);
      END_STATE();
    case 88:
      if (lookahead == 'a') ADVANCE(128);
      END_STATE();
    case 89:
      if (lookahead == 'l') ADVANCE(129);
      END_STATE();
    case 90:
      if (lookahead == 't') ADVANCE(130);
      END_STATE();
    case 91:
      ACCEPT_TOKEN(anon_sym_lua);
      END_STATE();
    case 92:
      ACCEPT_TOKEN(anon_sym_map);
      END_STATE();
    case 93:
      if (lookahead == 'e') ADVANCE(131);
      END_STATE();
    case 94:
      if (lookahead == 's') ADVANCE(132);
      END_STATE();
    case 95:
      if (lookahead == 'e') ADVANCE(133);
      END_STATE();
    case 96:
      if (lookahead == 'm') ADVANCE(134);
      END_STATE();
    case 97:
      if (lookahead == 'w') ADVANCE(135);
      END_STATE();
    case 98:
      if (lookahead == 'i') ADVANCE(136);
      END_STATE();
    case 99:
      if (lookahead == 'l') ADVANCE(137);
      END_STATE();
    case 100:
      ACCEPT_TOKEN(anon_sym_php);
      END_STATE();
    case 101:
      if (lookahead == 't') ADVANCE(138);
      END_STATE();
    case 102:
      if (lookahead == 'u') ADVANCE(139);
      END_STATE();
    case 103:
      if (lookahead == 'u') ADVANCE(140);
      END_STATE();
    case 104:
      if (lookahead == 'v') ADVANCE(141);
      END_STATE();
    case 105:
      ACCEPT_TOKEN(anon_sym_set);
      END_STATE();
    case 106:
      if (lookahead == 's') ADVANCE(142);
      END_STATE();
    case 107:
      if (lookahead == 'i') ADVANCE(143);
      if (lookahead == 'u') ADVANCE(144);
      END_STATE();
    case 108:
      if (lookahead == 'f') ADVANCE(145);
      END_STATE();
    case 109:
      if (lookahead == 'o') ADVANCE(146);
      END_STATE();
    case 110:
      if (lookahead == 'e') ADVANCE(147);
      END_STATE();
    case 111:
      if (lookahead == 'o') ADVANCE(148);
      END_STATE();
    case 112:
      if (lookahead == 'd') ADVANCE(149);
      END_STATE();
    case 113:
      ACCEPT_TOKEN(anon_sym_xsd);
      if (lookahead == '_') ADVANCE(150);
      END_STATE();
    case 114:
      if (lookahead == 'r') ADVANCE(151);
      END_STATE();
    case 115:
      ACCEPT_TOKEN(anon_sym_bool);
      END_STATE();
    case 116:
      ACCEPT_TOKEN(anon_sym_byte);
      END_STATE();
    case 117:
      if (lookahead == 'i') ADVANCE(152);
      END_STATE();
    case 118:
      if (lookahead == 't') ADVANCE(153);
      END_STATE();
    case 119:
      if (lookahead == 'i') ADVANCE(154);
      if (lookahead == 't') ADVANCE(155);
      END_STATE();
    case 120:
      ACCEPT_TOKEN(anon_sym_dart);
      END_STATE();
    case 121:
      if (lookahead == 'h') ADVANCE(156);
      END_STATE();
    case 122:
      if (lookahead == 'l') ADVANCE(157);
      END_STATE();
    case 123:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 124:
      if (lookahead == 'p') ADVANCE(158);
      END_STATE();
    case 125:
      if (lookahead == 'n') ADVANCE(159);
      END_STATE();
    case 126:
      ACCEPT_TOKEN(anon_sym_haxe);
      END_STATE();
    case 127:
      if (lookahead == 'u') ADVANCE(160);
      END_STATE();
    case 128:
      ACCEPT_TOKEN(anon_sym_java);
      if (lookahead == 'm') ADVANCE(161);
      END_STATE();
    case 129:
      if (lookahead == 'i') ADVANCE(162);
      END_STATE();
    case 130:
      ACCEPT_TOKEN(anon_sym_list);
      END_STATE();
    case 131:
      if (lookahead == 's') ADVANCE(163);
      END_STATE();
    case 132:
      if (lookahead == 't') ADVANCE(164);
      END_STATE();
    case 133:
      if (lookahead == 'j') ADVANCE(165);
      if (lookahead == 't') ADVANCE(166);
      END_STATE();
    case 134:
      if (lookahead == 'l') ADVANCE(167);
      END_STATE();
    case 135:
      if (lookahead == 'a') ADVANCE(168);
      END_STATE();
    case 136:
      if (lookahead == 'o') ADVANCE(169);
      END_STATE();
    case 137:
      ACCEPT_TOKEN(anon_sym_perl);
      END_STATE();
    case 138:
      if (lookahead == 'w') ADVANCE(170);
      END_STATE();
    case 139:
      if (lookahead == 'i') ADVANCE(171);
      END_STATE();
    case 140:
      if (lookahead == 'm') ADVANCE(172);
      END_STATE();
    case 141:
      if (lookahead == 'i') ADVANCE(173);
      END_STATE();
    case 142:
      if (lookahead == 't') ADVANCE(174);
      END_STATE();
    case 143:
      if (lookahead == 'n') ADVANCE(175);
      END_STATE();
    case 144:
      if (lookahead == 'c') ADVANCE(176);
      END_STATE();
    case 145:
      if (lookahead == 't') ADVANCE(177);
      END_STATE();
    case 146:
      if (lookahead == 'w') ADVANCE(178);
      END_STATE();
    case 147:
      if (lookahead == 'd') ADVANCE(179);
      END_STATE();
    case 148:
      if (lookahead == 'n') ADVANCE(180);
      END_STATE();
    case 149:
      ACCEPT_TOKEN(anon_sym_void);
      END_STATE();
    case 150:
      if (lookahead == 'a') ADVANCE(181);
      if (lookahead == 'n') ADVANCE(182);
      if (lookahead == 'o') ADVANCE(183);
      END_STATE();
    case 151:
      if (lookahead == 'y') ADVANCE(184);
      END_STATE();
    case 152:
      if (lookahead == 'b') ADVANCE(185);
      END_STATE();
    case 153:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 154:
      if (lookahead == 'n') ADVANCE(186);
      END_STATE();
    case 155:
      if (lookahead == 'y') ADVANCE(187);
      END_STATE();
    case 156:
      if (lookahead == 'i') ADVANCE(188);
      END_STATE();
    case 157:
      if (lookahead == 'e') ADVANCE(189);
      END_STATE();
    case 158:
      if (lookahead == 't') ADVANCE(190);
      END_STATE();
    case 159:
      if (lookahead == 'd') ADVANCE(191);
      END_STATE();
    case 160:
      if (lookahead == 'd') ADVANCE(192);
      END_STATE();
    case 161:
      if (lookahead == 'e') ADVANCE(193);
      END_STATE();
    case 162:
      if (lookahead == 'n') ADVANCE(194);
      END_STATE();
    case 163:
      if (lookahead == 'p') ADVANCE(195);
      END_STATE();
    case 164:
      if (lookahead == 'd') ADVANCE(196);
      END_STATE();
    case 165:
      if (lookahead == 's') ADVANCE(197);
      END_STATE();
    case 166:
      if (lookahead == 's') ADVANCE(198);
      END_STATE();
    case 167:
      ACCEPT_TOKEN(anon_sym_ocaml);
      END_STATE();
    case 168:
      if (lookahead == 'y') ADVANCE(199);
      END_STATE();
    case 169:
      if (lookahead == 'n') ADVANCE(200);
      END_STATE();
    case 170:
      if (lookahead == 'i') ADVANCE(201);
      END_STATE();
    case 171:
      if (lookahead == 'r') ADVANCE(202);
      END_STATE();
    case 172:
      ACCEPT_TOKEN(anon_sym_senum);
      END_STATE();
    case 173:
      if (lookahead == 'c') ADVANCE(203);
      END_STATE();
    case 174:
      ACCEPT_TOKEN(anon_sym_slist);
      END_STATE();
    case 175:
      if (lookahead == 'g') ADVANCE(204);
      END_STATE();
    case 176:
      if (lookahead == 't') ADVANCE(205);
      END_STATE();
    case 177:
      ACCEPT_TOKEN(anon_sym_swift);
      END_STATE();
    case 178:
      if (lookahead == 's') ADVANCE(206);
      END_STATE();
    case 179:
      if (lookahead == 'e') ADVANCE(207);
      END_STATE();
    case 180:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 181:
      if (lookahead == 'l') ADVANCE(208);
      if (lookahead == 't') ADVANCE(209);
      END_STATE();
    case 182:
      if (lookahead == 'i') ADVANCE(210);
      END_STATE();
    case 183:
      if (lookahead == 'p') ADVANCE(211);
      END_STATE();
    case 184:
      ACCEPT_TOKEN(anon_sym_binary);
      END_STATE();
    case 185:
      ACCEPT_TOKEN(anon_sym_c_glib);
      END_STATE();
    case 186:
      if (lookahead == 'c') ADVANCE(212);
      END_STATE();
    case 187:
      if (lookahead == 'p') ADVANCE(213);
      END_STATE();
    case 188:
      ACCEPT_TOKEN(anon_sym_delphi);
      END_STATE();
    case 189:
      ACCEPT_TOKEN(anon_sym_double);
      END_STATE();
    case 190:
      if (lookahead == 'i') ADVANCE(214);
      END_STATE();
    case 191:
      if (lookahead == 's') ADVANCE(215);
      END_STATE();
    case 192:
      if (lookahead == 'e') ADVANCE(216);
      END_STATE();
    case 193:
      ACCEPT_TOKEN(anon_sym_javame);
      END_STATE();
    case 194:
      ACCEPT_TOKEN(anon_sym_kotlin);
      END_STATE();
    case 195:
      if (lookahead == 'a') ADVANCE(217);
      END_STATE();
    case 196:
      ACCEPT_TOKEN(anon_sym_netstd);
      END_STATE();
    case 197:
      ACCEPT_TOKEN(anon_sym_nodejs);
      END_STATE();
    case 198:
      ACCEPT_TOKEN(anon_sym_nodets);
      END_STATE();
    case 199:
      ACCEPT_TOKEN(anon_sym_oneway);
      END_STATE();
    case 200:
      if (lookahead == 'a') ADVANCE(218);
      END_STATE();
    case 201:
      if (lookahead == 's') ADVANCE(219);
      END_STATE();
    case 202:
      if (lookahead == 'e') ADVANCE(220);
      END_STATE();
    case 203:
      if (lookahead == 'e') ADVANCE(221);
      END_STATE();
    case 204:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 205:
      ACCEPT_TOKEN(anon_sym_struct);
      END_STATE();
    case 206:
      ACCEPT_TOKEN(anon_sym_throws);
      END_STATE();
    case 207:
      if (lookahead == 'f') ADVANCE(222);
      END_STATE();
    case 208:
      if (lookahead == 'l') ADVANCE(223);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(224);
      END_STATE();
    case 210:
      if (lookahead == 'l') ADVANCE(225);
      END_STATE();
    case 211:
      if (lookahead == 't') ADVANCE(226);
      END_STATE();
    case 212:
      if (lookahead == 'l') ADVANCE(227);
      END_STATE();
    case 213:
      if (lookahead == 'e') ADVANCE(228);
      END_STATE();
    case 214:
      if (lookahead == 'o') ADVANCE(229);
      END_STATE();
    case 215:
      ACCEPT_TOKEN(anon_sym_extends);
      END_STATE();
    case 216:
      ACCEPT_TOKEN(anon_sym_include);
      END_STATE();
    case 217:
      if (lookahead == 'c') ADVANCE(230);
      END_STATE();
    case 218:
      if (lookahead == 'l') ADVANCE(231);
      END_STATE();
    case 219:
      if (lookahead == 't') ADVANCE(232);
      END_STATE();
    case 220:
      if (lookahead == 'd') ADVANCE(233);
      END_STATE();
    case 221:
      ACCEPT_TOKEN(anon_sym_service);
      END_STATE();
    case 222:
      ACCEPT_TOKEN(anon_sym_typedef);
      END_STATE();
    case 223:
      ACCEPT_TOKEN(anon_sym_xsd_all);
      END_STATE();
    case 224:
      if (lookahead == 'r') ADVANCE(234);
      END_STATE();
    case 225:
      if (lookahead == 'l') ADVANCE(235);
      END_STATE();
    case 226:
      if (lookahead == 'i') ADVANCE(236);
      END_STATE();
    case 227:
      if (lookahead == 'u') ADVANCE(237);
      END_STATE();
    case 228:
      ACCEPT_TOKEN(anon_sym_cpp_type);
      END_STATE();
    case 229:
      if (lookahead == 'n') ADVANCE(238);
      END_STATE();
    case 230:
      if (lookahead == 'e') ADVANCE(239);
      END_STATE();
    case 231:
      ACCEPT_TOKEN(anon_sym_optional);
      END_STATE();
    case 232:
      if (lookahead == 'e') ADVANCE(240);
      END_STATE();
    case 233:
      ACCEPT_TOKEN(anon_sym_required);
      END_STATE();
    case 234:
      if (lookahead == 's') ADVANCE(241);
      END_STATE();
    case 235:
      if (lookahead == 'a') ADVANCE(242);
      END_STATE();
    case 236:
      if (lookahead == 'o') ADVANCE(243);
      END_STATE();
    case 237:
      if (lookahead == 'd') ADVANCE(244);
      END_STATE();
    case 238:
      ACCEPT_TOKEN(anon_sym_exception);
      END_STATE();
    case 239:
      ACCEPT_TOKEN(anon_sym_namespace);
      END_STATE();
    case 240:
      if (lookahead == 'd') ADVANCE(245);
      END_STATE();
    case 241:
      ACCEPT_TOKEN(anon_sym_xsd_attrs);
      END_STATE();
    case 242:
      if (lookahead == 'b') ADVANCE(246);
      END_STATE();
    case 243:
      if (lookahead == 'n') ADVANCE(247);
      END_STATE();
    case 244:
      if (lookahead == 'e') ADVANCE(248);
      END_STATE();
    case 245:
      ACCEPT_TOKEN(anon_sym_py_DOTtwisted);
      END_STATE();
    case 246:
      if (lookahead == 'l') ADVANCE(249);
      END_STATE();
    case 247:
      if (lookahead == 'a') ADVANCE(250);
      END_STATE();
    case 248:
      ACCEPT_TOKEN(anon_sym_cpp_include);
      END_STATE();
    case 249:
      if (lookahead == 'e') ADVANCE(251);
      END_STATE();
    case 250:
      if (lookahead == 'l') ADVANCE(252);
      END_STATE();
    case 251:
      ACCEPT_TOKEN(anon_sym_xsd_nillable);
      END_STATE();
    case 252:
      ACCEPT_TOKEN(anon_sym_xsd_optional);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 0},
  [2] = {.lex_state = 0},
  [3] = {.lex_state = 3},
  [4] = {.lex_state = 3},
  [5] = {.lex_state = 3},
  [6] = {.lex_state = 3},
  [7] = {.lex_state = 3},
  [8] = {.lex_state = 3},
  [9] = {.lex_state = 3},
  [10] = {.lex_state = 3},
  [11] = {.lex_state = 3},
  [12] = {.lex_state = 3},
  [13] = {.lex_state = 3},
  [14] = {.lex_state = 3},
  [15] = {.lex_state = 3},
  [16] = {.lex_state = 3},
  [17] = {.lex_state = 3},
  [18] = {.lex_state = 3},
  [19] = {.lex_state = 3},
  [20] = {.lex_state = 3},
  [21] = {.lex_state = 3},
  [22] = {.lex_state = 3},
  [23] = {.lex_state = 3},
  [24] = {.lex_state = 3},
  [25] = {.lex_state = 0},
  [26] = {.lex_state = 0},
  [27] = {.lex_state = 3},
  [28] = {.lex_state = 3},
  [29] = {.lex_state = 0},
  [30] = {.lex_state = 3},
  [31] = {.lex_state = 0},
  [32] = {.lex_state = 0},
  [33] = {.lex_state = 0},
  [34] = {.lex_state = 3},
  [35] = {.lex_state = 3},
  [36] = {.lex_state = 3},
  [37] = {.lex_state = 3},
  [38] = {.lex_state = 3},
  [39] = {.lex_state = 3},
  [40] = {.lex_state = 3},
  [41] = {.lex_state = 3},
  [42] = {.lex_state = 3},
  [43] = {.lex_state = 3},
  [44] = {.lex_state = 3},
  [45] = {.lex_state = 3},
  [46] = {.lex_state = 3},
  [47] = {.lex_state = 3},
  [48] = {.lex_state = 3},
  [49] = {.lex_state = 3},
  [50] = {.lex_state = 0},
  [51] = {.lex_state = 0},
  [52] = {.lex_state = 3},
  [53] = {.lex_state = 0},
  [54] = {.lex_state = 0},
  [55] = {.lex_state = 3},
  [56] = {.lex_state = 3},
  [57] = {.lex_state = 3},
  [58] = {.lex_state = 3},
  [59] = {.lex_state = 0},
  [60] = {.lex_state = 3},
  [61] = {.lex_state = 3},
  [62] = {.lex_state = 3},
  [63] = {.lex_state = 3},
  [64] = {.lex_state = 3},
  [65] = {.lex_state = 0},
  [66] = {.lex_state = 0},
  [67] = {.lex_state = 0},
  [68] = {.lex_state = 0},
  [69] = {.lex_state = 0},
  [70] = {.lex_state = 0},
  [71] = {.lex_state = 0},
  [72] = {.lex_state = 0},
  [73] = {.lex_state = 0},
  [74] = {.lex_state = 0},
  [75] = {.lex_state = 0},
  [76] = {.lex_state = 0},
  [77] = {.lex_state = 0},
  [78] = {.lex_state = 3},
  [79] = {.lex_state = 3},
  [80] = {.lex_state = 3},
  [81] = {.lex_state = 3},
  [82] = {.lex_state = 3},
  [83] = {.lex_state = 3},
  [84] = {.lex_state = 0},
  [85] = {.lex_state = 0},
  [86] = {.lex_state = 0},
  [87] = {.lex_state = 0},
  [88] = {.lex_state = 0},
  [89] = {.lex_state = 3},
  [90] = {.lex_state = 3},
  [91] = {.lex_state = 0},
  [92] = {.lex_state = 0},
  [93] = {.lex_state = 0},
  [94] = {.lex_state = 0},
  [95] = {.lex_state = 0},
  [96] = {.lex_state = 0},
  [97] = {.lex_state = 0},
  [98] = {.lex_state = 0},
  [99] = {.lex_state = 0},
  [100] = {.lex_state = 0},
  [101] = {.lex_state = 0},
  [102] = {.lex_state = 0},
  [103] = {.lex_state = 0},
  [104] = {.lex_state = 0},
  [105] = {.lex_state = 0},
  [106] = {.lex_state = 0},
  [107] = {.lex_state = 0},
  [108] = {.lex_state = 0},
  [109] = {.lex_state = 0},
  [110] = {.lex_state = 0},
  [111] = {.lex_state = 0},
  [112] = {.lex_state = 0},
  [113] = {.lex_state = 0},
  [114] = {.lex_state = 0},
  [115] = {.lex_state = 0},
  [116] = {.lex_state = 0},
  [117] = {.lex_state = 0},
  [118] = {.lex_state = 0},
  [119] = {.lex_state = 0},
  [120] = {.lex_state = 0},
  [121] = {.lex_state = 0},
  [122] = {.lex_state = 0},
  [123] = {.lex_state = 0},
  [124] = {.lex_state = 0},
  [125] = {.lex_state = 0},
  [126] = {.lex_state = 0},
  [127] = {.lex_state = 0},
  [128] = {.lex_state = 0},
  [129] = {.lex_state = 0},
  [130] = {.lex_state = 0},
  [131] = {.lex_state = 0},
  [132] = {.lex_state = 0},
  [133] = {.lex_state = 0},
  [134] = {.lex_state = 0},
  [135] = {.lex_state = 0},
  [136] = {.lex_state = 0},
  [137] = {.lex_state = 0},
  [138] = {.lex_state = 0},
  [139] = {.lex_state = 0},
  [140] = {.lex_state = 0},
  [141] = {.lex_state = 0},
  [142] = {.lex_state = 0},
  [143] = {.lex_state = 0},
  [144] = {.lex_state = 0},
  [145] = {.lex_state = 0},
  [146] = {.lex_state = 0},
  [147] = {.lex_state = 0},
  [148] = {.lex_state = 0},
  [149] = {.lex_state = 0},
  [150] = {.lex_state = 0},
  [151] = {.lex_state = 0},
  [152] = {.lex_state = 0},
  [153] = {.lex_state = 0},
  [154] = {.lex_state = 0},
  [155] = {.lex_state = 0},
  [156] = {.lex_state = 0},
  [157] = {.lex_state = 0},
  [158] = {.lex_state = 0},
  [159] = {.lex_state = 0},
  [160] = {.lex_state = 0},
  [161] = {.lex_state = 0},
  [162] = {.lex_state = 0},
  [163] = {.lex_state = 0},
  [164] = {.lex_state = 0},
  [165] = {.lex_state = 0},
  [166] = {.lex_state = 0},
  [167] = {.lex_state = 0},
  [168] = {.lex_state = 0},
  [169] = {.lex_state = 0},
  [170] = {.lex_state = 0},
  [171] = {.lex_state = 0},
  [172] = {.lex_state = 0},
  [173] = {.lex_state = 0},
  [174] = {.lex_state = 0},
  [175] = {.lex_state = 0},
  [176] = {.lex_state = 0},
  [177] = {.lex_state = 0},
  [178] = {.lex_state = 0},
  [179] = {.lex_state = 0},
  [180] = {.lex_state = 0},
  [181] = {.lex_state = 0},
  [182] = {.lex_state = 0},
  [183] = {.lex_state = 0},
  [184] = {.lex_state = 0},
  [185] = {.lex_state = 0},
  [186] = {.lex_state = 0},
  [187] = {.lex_state = 0},
  [188] = {.lex_state = 0},
  [189] = {.lex_state = 0},
  [190] = {.lex_state = 0},
  [191] = {.lex_state = 0},
  [192] = {.lex_state = 0},
  [193] = {.lex_state = 0},
  [194] = {.lex_state = 0},
  [195] = {.lex_state = 3},
  [196] = {.lex_state = 0},
  [197] = {.lex_state = 0},
  [198] = {.lex_state = 0},
  [199] = {.lex_state = 0},
  [200] = {.lex_state = 0},
  [201] = {.lex_state = 0},
  [202] = {.lex_state = 0},
  [203] = {.lex_state = 0},
  [204] = {.lex_state = 0},
  [205] = {.lex_state = 0},
  [206] = {.lex_state = 0},
  [207] = {.lex_state = 0},
  [208] = {.lex_state = 0},
  [209] = {.lex_state = 0},
  [210] = {.lex_state = 0},
  [211] = {.lex_state = 0},
  [212] = {.lex_state = 0},
  [213] = {.lex_state = 0},
  [214] = {.lex_state = 0},
  [215] = {.lex_state = 0},
  [216] = {.lex_state = 0},
  [217] = {.lex_state = 0},
  [218] = {.lex_state = 0},
  [219] = {.lex_state = 0},
  [220] = {.lex_state = 0},
  [221] = {.lex_state = 0},
  [222] = {.lex_state = 0},
  [223] = {.lex_state = 0},
  [224] = {.lex_state = 0},
  [225] = {.lex_state = 0},
  [226] = {.lex_state = 0},
  [227] = {.lex_state = 0},
  [228] = {.lex_state = 0},
  [229] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_identifier] = ACTIONS(1),
    [anon_sym_include] = ACTIONS(1),
    [anon_sym_cpp_include] = ACTIONS(1),
    [anon_sym_namespace] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_c_glib] = ACTIONS(1),
    [anon_sym_cpp] = ACTIONS(1),
    [anon_sym_d] = ACTIONS(1),
    [anon_sym_dart] = ACTIONS(1),
    [anon_sym_delphi] = ACTIONS(1),
    [anon_sym_erl] = ACTIONS(1),
    [anon_sym_go] = ACTIONS(1),
    [anon_sym_haxe] = ACTIONS(1),
    [anon_sym_java] = ACTIONS(1),
    [anon_sym_javame] = ACTIONS(1),
    [anon_sym_js] = ACTIONS(1),
    [anon_sym_kotlin] = ACTIONS(1),
    [anon_sym_lua] = ACTIONS(1),
    [anon_sym_netstd] = ACTIONS(1),
    [anon_sym_nodejs] = ACTIONS(1),
    [anon_sym_nodets] = ACTIONS(1),
    [anon_sym_ocaml] = ACTIONS(1),
    [anon_sym_perl] = ACTIONS(1),
    [anon_sym_php] = ACTIONS(1),
    [anon_sym_py] = ACTIONS(1),
    [anon_sym_py_DOTtwisted] = ACTIONS(1),
    [anon_sym_rb] = ACTIONS(1),
    [anon_sym_rs] = ACTIONS(1),
    [anon_sym_st] = ACTIONS(1),
    [anon_sym_swift] = ACTIONS(1),
    [anon_sym_ts] = ACTIONS(1),
    [anon_sym_xsd] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_typedef] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_senum] = ACTIONS(1),
    [anon_sym_struct] = ACTIONS(1),
    [anon_sym_xsd_all] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_exception] = ACTIONS(1),
    [anon_sym_service] = ACTIONS(1),
    [anon_sym_extends] = ACTIONS(1),
    [anon_sym_xsd_optional] = ACTIONS(1),
    [anon_sym_xsd_nillable] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_required] = ACTIONS(1),
    [anon_sym_optional] = ACTIONS(1),
    [anon_sym_xsd_attrs] = ACTIONS(1),
    [anon_sym_oneway] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_void] = ACTIONS(1),
    [anon_sym_throws] = ACTIONS(1),
    [anon_sym_bool] = ACTIONS(1),
    [anon_sym_byte] = ACTIONS(1),
    [anon_sym_i8] = ACTIONS(1),
    [anon_sym_i16] = ACTIONS(1),
    [anon_sym_i32] = ACTIONS(1),
    [anon_sym_i64] = ACTIONS(1),
    [anon_sym_double] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_binary] = ACTIONS(1),
    [anon_sym_slist] = ACTIONS(1),
    [anon_sym_map] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_set] = ACTIONS(1),
    [anon_sym_list] = ACTIONS(1),
    [anon_sym_cpp_type] = ACTIONS(1),
    [sym_int_constant] = ACTIONS(1),
    [sym_double_constant] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [sym_literal] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
  },
  [1] = {
    [sym_document] = STATE(222),
    [sym_header] = STATE(25),
    [sym_include] = STATE(104),
    [sym_cpp_include] = STATE(104),
    [sym_namespace] = STATE(104),
    [sym_definition] = STATE(88),
    [sym_const] = STATE(133),
    [sym_typedef] = STATE(133),
    [sym_enum] = STATE(133),
    [sym_senum] = STATE(133),
    [sym_struct] = STATE(133),
    [sym_union] = STATE(133),
    [sym_exception] = STATE(133),
    [sym_service] = STATE(133),
    [aux_sym_document_repeat1] = STATE(25),
    [aux_sym_document_repeat2] = STATE(88),
    [ts_builtin_sym_end] = ACTIONS(5),
    [anon_sym_include] = ACTIONS(7),
    [anon_sym_cpp_include] = ACTIONS(9),
    [anon_sym_namespace] = ACTIONS(11),
    [anon_sym_const] = ACTIONS(13),
    [anon_sym_typedef] = ACTIONS(15),
    [anon_sym_enum] = ACTIONS(17),
    [anon_sym_senum] = ACTIONS(19),
    [anon_sym_struct] = ACTIONS(21),
    [anon_sym_union] = ACTIONS(23),
    [anon_sym_exception] = ACTIONS(25),
    [anon_sym_service] = ACTIONS(27),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(219), 1,
      sym_namespace_scope,
    ACTIONS(31), 3,
      anon_sym_d,
      anon_sym_java,
      anon_sym_py,
    ACTIONS(29), 25,
      anon_sym_STAR,
      anon_sym_c_glib,
      anon_sym_cpp,
      anon_sym_dart,
      anon_sym_delphi,
      anon_sym_erl,
      anon_sym_go,
      anon_sym_haxe,
      anon_sym_javame,
      anon_sym_js,
      anon_sym_kotlin,
      anon_sym_lua,
      anon_sym_netstd,
      anon_sym_nodejs,
      anon_sym_nodets,
      anon_sym_ocaml,
      anon_sym_perl,
      anon_sym_php,
      anon_sym_py_DOTtwisted,
      anon_sym_rb,
      anon_sym_rs,
      anon_sym_st,
      anon_sym_swift,
      anon_sym_ts,
      anon_sym_xsd,
  [39] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      sym_identifier,
    ACTIONS(44), 1,
      anon_sym_map,
    ACTIONS(47), 1,
      anon_sym_set,
    ACTIONS(50), 1,
      anon_sym_list,
    ACTIONS(53), 1,
      sym_int_constant,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(36), 2,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
    ACTIONS(38), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(41), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [100] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(60), 1,
      anon_sym_RPAREN,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [160] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(72), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(10), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [220] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(74), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(18), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [280] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(76), 1,
      anon_sym_RPAREN,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(13), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [340] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(78), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(21), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [400] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(80), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(17), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [460] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(82), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [520] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(84), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(12), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [580] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(86), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [640] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(88), 1,
      anon_sym_RPAREN,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [700] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(90), 1,
      anon_sym_RPAREN,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(4), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [760] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(60), 1,
      anon_sym_RPAREN,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(19), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [820] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(92), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(20), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [880] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(94), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [940] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(84), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1000] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(96), 1,
      anon_sym_RPAREN,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1060] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(98), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1120] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(70), 1,
      sym_int_constant,
    ACTIONS(80), 1,
      anon_sym_RBRACE,
    STATE(50), 1,
      sym_field_id,
    STATE(73), 1,
      sym_field_req,
    STATE(205), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(3), 2,
      sym_field,
      aux_sym_struct_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1180] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(102), 1,
      anon_sym_EQ,
    ACTIONS(106), 1,
      anon_sym_xsd_optional,
    ACTIONS(108), 1,
      anon_sym_xsd_nillable,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(57), 1,
      sym_xsd_attrs,
    STATE(80), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(104), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(100), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1229] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    ACTIONS(116), 1,
      anon_sym_EQ,
    ACTIONS(120), 1,
      anon_sym_xsd_optional,
    ACTIONS(122), 1,
      anon_sym_xsd_nillable,
    STATE(56), 1,
      sym_xsd_attrs,
    STATE(89), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(118), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(114), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1278] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    ACTIONS(126), 1,
      anon_sym_EQ,
    ACTIONS(130), 1,
      anon_sym_xsd_optional,
    ACTIONS(132), 1,
      anon_sym_xsd_nillable,
    STATE(61), 1,
      sym_xsd_attrs,
    STATE(81), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(128), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(124), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1327] = 17,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      anon_sym_include,
    ACTIONS(9), 1,
      anon_sym_cpp_include,
    ACTIONS(11), 1,
      anon_sym_namespace,
    ACTIONS(13), 1,
      anon_sym_const,
    ACTIONS(15), 1,
      anon_sym_typedef,
    ACTIONS(17), 1,
      anon_sym_enum,
    ACTIONS(19), 1,
      anon_sym_senum,
    ACTIONS(21), 1,
      anon_sym_struct,
    ACTIONS(23), 1,
      anon_sym_union,
    ACTIONS(25), 1,
      anon_sym_exception,
    ACTIONS(27), 1,
      anon_sym_service,
    ACTIONS(134), 1,
      ts_builtin_sym_end,
    STATE(87), 2,
      sym_definition,
      aux_sym_document_repeat2,
    STATE(95), 2,
      sym_header,
      aux_sym_document_repeat1,
    STATE(104), 3,
      sym_include,
      sym_cpp_include,
      sym_namespace,
    STATE(133), 8,
      sym_const,
      sym_typedef,
      sym_enum,
      sym_senum,
      sym_struct,
      sym_union,
      sym_exception,
      sym_service,
  [1390] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(136), 1,
      anon_sym_RBRACE,
    ACTIONS(138), 1,
      anon_sym_oneway,
    ACTIONS(140), 1,
      anon_sym_void,
    STATE(197), 1,
      sym_function_type,
    STATE(201), 1,
      sym_field_type,
    STATE(33), 2,
      sym_function,
      aux_sym_service_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1446] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    ACTIONS(146), 1,
      anon_sym_xsd_optional,
    ACTIONS(148), 1,
      anon_sym_xsd_nillable,
    STATE(62), 1,
      sym_xsd_attrs,
    STATE(82), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(144), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(142), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1492] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(106), 1,
      anon_sym_xsd_optional,
    ACTIONS(108), 1,
      anon_sym_xsd_nillable,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(57), 1,
      sym_xsd_attrs,
    STATE(80), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(104), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(100), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1538] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(138), 1,
      anon_sym_oneway,
    ACTIONS(140), 1,
      anon_sym_void,
    ACTIONS(150), 1,
      anon_sym_RBRACE,
    STATE(197), 1,
      sym_function_type,
    STATE(201), 1,
      sym_field_type,
    STATE(32), 2,
      sym_function,
      aux_sym_service_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1594] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    ACTIONS(156), 1,
      anon_sym_xsd_optional,
    ACTIONS(158), 1,
      anon_sym_xsd_nillable,
    STATE(55), 1,
      sym_xsd_attrs,
    STATE(83), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(154), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(152), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1640] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(138), 1,
      anon_sym_oneway,
    ACTIONS(140), 1,
      anon_sym_void,
    ACTIONS(160), 1,
      anon_sym_RBRACE,
    STATE(197), 1,
      sym_function_type,
    STATE(201), 1,
      sym_field_type,
    STATE(29), 2,
      sym_function,
      aux_sym_service_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1696] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(162), 1,
      sym_identifier,
    ACTIONS(165), 1,
      anon_sym_RBRACE,
    ACTIONS(167), 1,
      anon_sym_oneway,
    ACTIONS(170), 1,
      anon_sym_void,
    ACTIONS(176), 1,
      anon_sym_map,
    ACTIONS(179), 1,
      anon_sym_set,
    ACTIONS(182), 1,
      anon_sym_list,
    STATE(197), 1,
      sym_function_type,
    STATE(201), 1,
      sym_field_type,
    STATE(32), 2,
      sym_function,
      aux_sym_service_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(173), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1752] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(138), 1,
      anon_sym_oneway,
    ACTIONS(140), 1,
      anon_sym_void,
    ACTIONS(185), 1,
      anon_sym_RBRACE,
    STATE(197), 1,
      sym_function_type,
    STATE(201), 1,
      sym_field_type,
    STATE(32), 2,
      sym_function,
      aux_sym_service_repeat1,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [1808] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    ACTIONS(148), 1,
      anon_sym_xsd_nillable,
    STATE(62), 1,
      sym_xsd_attrs,
    STATE(82), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(144), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(142), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1851] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    ACTIONS(158), 1,
      anon_sym_xsd_nillable,
    STATE(55), 1,
      sym_xsd_attrs,
    STATE(83), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(154), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(152), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1894] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(108), 1,
      anon_sym_xsd_nillable,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(57), 1,
      sym_xsd_attrs,
    STATE(80), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(104), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(100), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1937] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    ACTIONS(122), 1,
      anon_sym_xsd_nillable,
    STATE(56), 1,
      sym_xsd_attrs,
    STATE(89), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(118), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(114), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [1980] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    ACTIONS(191), 1,
      anon_sym_xsd_nillable,
    STATE(60), 1,
      sym_xsd_attrs,
    STATE(78), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(189), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(187), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2023] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(195), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      sym_int_constant,
      anon_sym_SEMI,
    ACTIONS(193), 19,
      anon_sym_xsd_optional,
      anon_sym_xsd_nillable,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_xsd_attrs,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(199), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      sym_int_constant,
      anon_sym_SEMI,
    ACTIONS(197), 19,
      anon_sym_xsd_optional,
      anon_sym_xsd_nillable,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_xsd_attrs,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2087] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(55), 1,
      sym_xsd_attrs,
    STATE(83), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(154), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(152), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2127] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(62), 1,
      sym_xsd_attrs,
    STATE(82), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(144), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(142), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2167] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(60), 1,
      sym_xsd_attrs,
    STATE(78), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(189), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(187), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2207] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(203), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      sym_int_constant,
      anon_sym_SEMI,
    ACTIONS(201), 19,
      anon_sym_xsd_optional,
      anon_sym_xsd_nillable,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_xsd_attrs,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2239] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(207), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      sym_int_constant,
      anon_sym_SEMI,
    ACTIONS(205), 19,
      anon_sym_xsd_optional,
      anon_sym_xsd_nillable,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_xsd_attrs,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2271] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(52), 1,
      sym_xsd_attrs,
    STATE(79), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(211), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(209), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2311] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(215), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      sym_int_constant,
      anon_sym_SEMI,
    ACTIONS(213), 19,
      anon_sym_xsd_optional,
      anon_sym_xsd_nillable,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_xsd_attrs,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2343] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(56), 1,
      sym_xsd_attrs,
    STATE(89), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(118), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(114), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2383] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(110), 1,
      anon_sym_xsd_attrs,
    STATE(57), 1,
      sym_xsd_attrs,
    STATE(80), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(104), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(100), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2423] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(75), 1,
      sym_field_req,
    STATE(204), 1,
      sym_field_type,
    ACTIONS(58), 2,
      anon_sym_required,
      anon_sym_optional,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [2470] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(219), 1,
      anon_sym_RBRACE,
    ACTIONS(221), 1,
      anon_sym_throws,
    STATE(69), 1,
      sym_throws,
    STATE(92), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(217), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2508] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(90), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(225), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(223), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2542] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    ACTIONS(140), 1,
      anon_sym_void,
    STATE(201), 1,
      sym_field_type,
    STATE(221), 1,
      sym_function_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [2588] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(221), 1,
      anon_sym_throws,
    ACTIONS(229), 1,
      anon_sym_RBRACE,
    STATE(74), 1,
      sym_throws,
    STATE(94), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(227), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2626] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(78), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(189), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(187), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2660] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(80), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(104), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(100), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2694] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(82), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(144), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(142), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2728] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(233), 4,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
      sym_literal,
    ACTIONS(231), 18,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2758] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(221), 1,
      anon_sym_throws,
    ACTIONS(237), 1,
      anon_sym_RBRACE,
    STATE(72), 1,
      sym_throws,
    STATE(93), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(235), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2796] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(79), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(211), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(209), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2830] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(89), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(118), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(114), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2864] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(83), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(154), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(152), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2898] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(241), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      sym_int_constant,
      anon_sym_SEMI,
    ACTIONS(239), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2927] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(245), 5,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      sym_int_constant,
      anon_sym_SEMI,
    ACTIONS(243), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [2956] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(191), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [2996] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(190), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3036] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(188), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3076] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(215), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3116] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(237), 1,
      anon_sym_RBRACE,
    STATE(93), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(235), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3148] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(187), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3188] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(189), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3228] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(229), 1,
      anon_sym_RBRACE,
    STATE(94), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(227), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3260] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(204), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3300] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(249), 1,
      anon_sym_RBRACE,
    STATE(96), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(247), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3332] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(202), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3372] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(211), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3412] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(56), 1,
      sym_identifier,
    ACTIONS(64), 1,
      anon_sym_map,
    ACTIONS(66), 1,
      anon_sym_set,
    ACTIONS(68), 1,
      anon_sym_list,
    STATE(212), 1,
      sym_field_type,
    STATE(167), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(62), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3452] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(211), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(209), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3479] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(225), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(223), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3506] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(144), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(142), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3533] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(118), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(114), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3560] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(154), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(152), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3587] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(189), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(187), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3614] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(253), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(251), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3641] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(257), 1,
      anon_sym_map,
    ACTIONS(259), 1,
      anon_sym_set,
    ACTIONS(261), 1,
      anon_sym_list,
    STATE(192), 1,
      sym_definition_type,
    STATE(196), 2,
      sym_base_type,
      sym_container_type,
    STATE(165), 3,
      sym_map_type,
      sym_set_type,
      sym_list_type,
    ACTIONS(255), 10,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
  [3678] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(263), 1,
      ts_builtin_sym_end,
    ACTIONS(265), 1,
      anon_sym_const,
    ACTIONS(268), 1,
      anon_sym_typedef,
    ACTIONS(271), 1,
      anon_sym_enum,
    ACTIONS(274), 1,
      anon_sym_senum,
    ACTIONS(277), 1,
      anon_sym_struct,
    ACTIONS(280), 1,
      anon_sym_union,
    ACTIONS(283), 1,
      anon_sym_exception,
    ACTIONS(286), 1,
      anon_sym_service,
    STATE(86), 2,
      sym_definition,
      aux_sym_document_repeat2,
    STATE(133), 8,
      sym_const,
      sym_typedef,
      sym_enum,
      sym_senum,
      sym_struct,
      sym_union,
      sym_exception,
      sym_service,
  [3723] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_const,
    ACTIONS(15), 1,
      anon_sym_typedef,
    ACTIONS(17), 1,
      anon_sym_enum,
    ACTIONS(19), 1,
      anon_sym_senum,
    ACTIONS(21), 1,
      anon_sym_struct,
    ACTIONS(23), 1,
      anon_sym_union,
    ACTIONS(25), 1,
      anon_sym_exception,
    ACTIONS(27), 1,
      anon_sym_service,
    ACTIONS(289), 1,
      ts_builtin_sym_end,
    STATE(86), 2,
      sym_definition,
      aux_sym_document_repeat2,
    STATE(133), 8,
      sym_const,
      sym_typedef,
      sym_enum,
      sym_senum,
      sym_struct,
      sym_union,
      sym_exception,
      sym_service,
  [3768] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(13), 1,
      anon_sym_const,
    ACTIONS(15), 1,
      anon_sym_typedef,
    ACTIONS(17), 1,
      anon_sym_enum,
    ACTIONS(19), 1,
      anon_sym_senum,
    ACTIONS(21), 1,
      anon_sym_struct,
    ACTIONS(23), 1,
      anon_sym_union,
    ACTIONS(25), 1,
      anon_sym_exception,
    ACTIONS(27), 1,
      anon_sym_service,
    ACTIONS(134), 1,
      ts_builtin_sym_end,
    STATE(86), 2,
      sym_definition,
      aux_sym_document_repeat2,
    STATE(133), 8,
      sym_const,
      sym_typedef,
      sym_enum,
      sym_senum,
      sym_struct,
      sym_union,
      sym_exception,
      sym_service,
  [3813] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(104), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(100), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3840] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(293), 3,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      sym_int_constant,
    ACTIONS(291), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3867] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(297), 3,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(295), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3894] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(237), 1,
      anon_sym_RBRACE,
    ACTIONS(235), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3919] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(229), 1,
      anon_sym_RBRACE,
    ACTIONS(227), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(249), 1,
      anon_sym_RBRACE,
    ACTIONS(247), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [3969] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(301), 1,
      anon_sym_include,
    ACTIONS(304), 1,
      anon_sym_cpp_include,
    ACTIONS(307), 1,
      anon_sym_namespace,
    STATE(95), 2,
      sym_header,
      aux_sym_document_repeat1,
    STATE(104), 3,
      sym_include,
      sym_cpp_include,
      sym_namespace,
    ACTIONS(299), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4002] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(312), 1,
      anon_sym_RBRACE,
    ACTIONS(310), 16,
      anon_sym_oneway,
      anon_sym_void,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [4027] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(314), 16,
      anon_sym_required,
      anon_sym_optional,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [4049] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(316), 14,
      anon_sym_bool,
      anon_sym_byte,
      anon_sym_i8,
      anon_sym_i16,
      anon_sym_i32,
      anon_sym_i64,
      anon_sym_double,
      anon_sym_string,
      anon_sym_binary,
      anon_sym_slist,
      anon_sym_map,
      anon_sym_set,
      anon_sym_list,
      sym_identifier,
  [4069] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(207), 12,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [4087] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(195), 12,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [4105] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(150), 1,
      sym_list_separator,
    ACTIONS(320), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(318), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4127] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 12,
      ts_builtin_sym_end,
      anon_sym_include,
      anon_sym_cpp_include,
      anon_sym_namespace,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4145] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(215), 12,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [4163] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(324), 12,
      ts_builtin_sym_end,
      anon_sym_include,
      anon_sym_cpp_include,
      anon_sym_namespace,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(203), 12,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [4199] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(326), 12,
      ts_builtin_sym_end,
      anon_sym_include,
      anon_sym_cpp_include,
      anon_sym_namespace,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4217] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(328), 12,
      ts_builtin_sym_end,
      anon_sym_include,
      anon_sym_cpp_include,
      anon_sym_namespace,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4235] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(199), 12,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_SEMI,
  [4253] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_LBRACE,
    ACTIONS(336), 1,
      anon_sym_LBRACK,
    ACTIONS(338), 1,
      anon_sym_RBRACK,
    STATE(113), 1,
      aux_sym_const_list_repeat1,
    STATE(124), 1,
      sym_const_value,
    ACTIONS(330), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(334), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(127), 2,
      sym_const_list,
      sym_const_map,
  [4284] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(343), 1,
      anon_sym_LBRACE,
    ACTIONS(346), 1,
      anon_sym_RBRACE,
    ACTIONS(351), 1,
      anon_sym_LBRACK,
    STATE(110), 1,
      aux_sym_const_map_repeat1,
    STATE(218), 1,
      sym_const_value,
    ACTIONS(340), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(348), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(105), 2,
      sym_const_list,
      sym_const_map,
  [4315] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_LBRACE,
    ACTIONS(358), 1,
      anon_sym_RBRACE,
    ACTIONS(362), 1,
      anon_sym_LBRACK,
    STATE(110), 1,
      aux_sym_const_map_repeat1,
    STATE(218), 1,
      sym_const_value,
    ACTIONS(354), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(360), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(105), 2,
      sym_const_list,
      sym_const_map,
  [4346] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_LBRACE,
    ACTIONS(336), 1,
      anon_sym_LBRACK,
    ACTIONS(364), 1,
      anon_sym_RBRACK,
    STATE(113), 1,
      aux_sym_const_list_repeat1,
    STATE(124), 1,
      sym_const_value,
    ACTIONS(330), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(334), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(127), 2,
      sym_const_list,
      sym_const_map,
  [4377] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(369), 1,
      anon_sym_LBRACE,
    ACTIONS(375), 1,
      anon_sym_LBRACK,
    ACTIONS(378), 1,
      anon_sym_RBRACK,
    STATE(113), 1,
      aux_sym_const_list_repeat1,
    STATE(124), 1,
      sym_const_value,
    ACTIONS(366), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(372), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(127), 2,
      sym_const_list,
      sym_const_map,
  [4408] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_LBRACE,
    ACTIONS(336), 1,
      anon_sym_LBRACK,
    ACTIONS(380), 1,
      anon_sym_RBRACK,
    STATE(112), 1,
      aux_sym_const_list_repeat1,
    STATE(124), 1,
      sym_const_value,
    ACTIONS(330), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(334), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(127), 2,
      sym_const_list,
      sym_const_map,
  [4439] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_LBRACE,
    ACTIONS(362), 1,
      anon_sym_LBRACK,
    ACTIONS(382), 1,
      anon_sym_RBRACE,
    STATE(120), 1,
      aux_sym_const_map_repeat1,
    STATE(218), 1,
      sym_const_value,
    ACTIONS(354), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(360), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(105), 2,
      sym_const_list,
      sym_const_map,
  [4470] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_LBRACE,
    ACTIONS(362), 1,
      anon_sym_LBRACK,
    ACTIONS(384), 1,
      anon_sym_RBRACE,
    STATE(118), 1,
      aux_sym_const_map_repeat1,
    STATE(218), 1,
      sym_const_value,
    ACTIONS(354), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(360), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(105), 2,
      sym_const_list,
      sym_const_map,
  [4501] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_LBRACE,
    ACTIONS(336), 1,
      anon_sym_LBRACK,
    ACTIONS(386), 1,
      anon_sym_RBRACK,
    STATE(109), 1,
      aux_sym_const_list_repeat1,
    STATE(124), 1,
      sym_const_value,
    ACTIONS(330), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(334), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(127), 2,
      sym_const_list,
      sym_const_map,
  [4532] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_LBRACE,
    ACTIONS(362), 1,
      anon_sym_LBRACK,
    ACTIONS(388), 1,
      anon_sym_RBRACE,
    STATE(110), 1,
      aux_sym_const_map_repeat1,
    STATE(218), 1,
      sym_const_value,
    ACTIONS(354), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(360), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(105), 2,
      sym_const_list,
      sym_const_map,
  [4563] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_LBRACE,
    ACTIONS(362), 1,
      anon_sym_LBRACK,
    ACTIONS(390), 1,
      anon_sym_RBRACE,
    STATE(111), 1,
      aux_sym_const_map_repeat1,
    STATE(218), 1,
      sym_const_value,
    ACTIONS(354), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(360), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(105), 2,
      sym_const_list,
      sym_const_map,
  [4594] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_LBRACE,
    ACTIONS(362), 1,
      anon_sym_LBRACK,
    ACTIONS(392), 1,
      anon_sym_RBRACE,
    STATE(110), 1,
      aux_sym_const_map_repeat1,
    STATE(218), 1,
      sym_const_value,
    ACTIONS(354), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(360), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(105), 2,
      sym_const_list,
      sym_const_map,
  [4625] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_LBRACE,
    ACTIONS(336), 1,
      anon_sym_LBRACK,
    ACTIONS(394), 1,
      anon_sym_RBRACK,
    STATE(122), 1,
      aux_sym_const_list_repeat1,
    STATE(124), 1,
      sym_const_value,
    ACTIONS(330), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(334), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(127), 2,
      sym_const_list,
      sym_const_map,
  [4656] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_LBRACE,
    ACTIONS(336), 1,
      anon_sym_LBRACK,
    ACTIONS(396), 1,
      anon_sym_RBRACK,
    STATE(113), 1,
      aux_sym_const_list_repeat1,
    STATE(124), 1,
      sym_const_value,
    ACTIONS(330), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(334), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(127), 2,
      sym_const_list,
      sym_const_map,
  [4687] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(193), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(195), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_literal,
      sym_identifier,
      anon_sym_SEMI,
  [4705] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(156), 1,
      sym_list_separator,
    ACTIONS(400), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(402), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(398), 5,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_literal,
      sym_identifier,
  [4727] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(205), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(207), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_literal,
      sym_identifier,
      anon_sym_SEMI,
  [4745] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(213), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(215), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_literal,
      sym_identifier,
      anon_sym_SEMI,
  [4763] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(201), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(203), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_literal,
      sym_identifier,
      anon_sym_SEMI,
  [4781] = 5,
    ACTIONS(3), 1,
      sym_comment,
    STATE(157), 1,
      sym_list_separator,
    ACTIONS(400), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(406), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(404), 5,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      sym_literal,
      sym_identifier,
  [4803] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(197), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(199), 8,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_literal,
      sym_identifier,
      anon_sym_SEMI,
  [4821] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(408), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4836] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(410), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4851] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(412), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4866] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(414), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4881] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(416), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4896] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(420), 1,
      anon_sym_LBRACE,
    ACTIONS(424), 1,
      anon_sym_LBRACK,
    STATE(28), 1,
      sym_const_value,
    ACTIONS(418), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(422), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(44), 2,
      sym_const_list,
      sym_const_map,
  [4921] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(426), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4936] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(428), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4951] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(430), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [4966] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(420), 1,
      anon_sym_LBRACE,
    ACTIONS(424), 1,
      anon_sym_LBRACK,
    STATE(30), 1,
      sym_const_value,
    ACTIONS(418), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(422), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(44), 2,
      sym_const_list,
      sym_const_map,
  [4991] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(432), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5006] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(434), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5021] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(436), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5036] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(233), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5051] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(438), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5066] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(440), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5081] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(442), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5096] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      anon_sym_LBRACE,
    ACTIONS(362), 1,
      anon_sym_LBRACK,
    STATE(101), 1,
      sym_const_value,
    ACTIONS(354), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(360), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(105), 2,
      sym_const_list,
      sym_const_map,
  [5121] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(444), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5136] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(332), 1,
      anon_sym_LBRACE,
    ACTIONS(336), 1,
      anon_sym_LBRACK,
    STATE(128), 1,
      sym_const_value,
    ACTIONS(330), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(334), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(127), 2,
      sym_const_list,
      sym_const_map,
  [5161] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(446), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5176] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(448), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5191] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(450), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5206] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(452), 9,
      ts_builtin_sym_end,
      anon_sym_const,
      anon_sym_typedef,
      anon_sym_enum,
      anon_sym_senum,
      anon_sym_struct,
      anon_sym_union,
      anon_sym_exception,
      anon_sym_service,
  [5221] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(420), 1,
      anon_sym_LBRACE,
    ACTIONS(424), 1,
      anon_sym_LBRACK,
    STATE(27), 1,
      sym_const_value,
    ACTIONS(418), 2,
      sym_literal,
      sym_identifier,
    ACTIONS(422), 2,
      sym_int_constant,
      sym_double_constant,
    STATE(44), 2,
      sym_const_list,
      sym_const_map,
  [5246] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(231), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(233), 6,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_literal,
      sym_identifier,
  [5262] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(454), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(378), 5,
      anon_sym_LBRACE,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      sym_literal,
      sym_identifier,
  [5277] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(458), 2,
      sym_int_constant,
      sym_double_constant,
    ACTIONS(456), 5,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LBRACK,
      sym_literal,
      sym_identifier,
  [5292] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(462), 1,
      anon_sym_EQ,
    STATE(180), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(460), 2,
      anon_sym_RBRACE,
      sym_identifier,
  [5310] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(464), 1,
      sym_identifier,
    ACTIONS(468), 1,
      anon_sym_cpp_type,
    ACTIONS(470), 1,
      sym_literal,
    STATE(176), 1,
      sym_cpp_type,
    ACTIONS(466), 2,
      anon_sym_COMMA,
      anon_sym_GT,
  [5330] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(183), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(472), 2,
      anon_sym_RBRACE,
      sym_identifier,
  [5345] = 4,
    ACTIONS(3), 1,
      sym_comment,
    STATE(184), 1,
      sym_list_separator,
    ACTIONS(112), 2,
      anon_sym_COMMA,
      anon_sym_SEMI,
    ACTIONS(474), 2,
      anon_sym_RBRACE,
      sym_literal,
  [5360] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(476), 4,
      anon_sym_LT,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5370] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(478), 1,
      anon_sym_LT,
    STATE(200), 1,
      sym_cpp_type,
    ACTIONS(470), 2,
      anon_sym_cpp_type,
      sym_literal,
  [5384] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(480), 1,
      anon_sym_LT,
    STATE(199), 1,
      sym_cpp_type,
    ACTIONS(470), 2,
      anon_sym_cpp_type,
      sym_literal,
  [5398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(482), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5407] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(484), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5416] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(486), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5425] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(488), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5434] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(490), 1,
      anon_sym_RBRACE,
    ACTIONS(492), 1,
      sym_literal,
    STATE(169), 1,
      aux_sym_senum_repeat1,
  [5447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(495), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5456] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 1,
      sym_identifier,
    ACTIONS(499), 1,
      anon_sym_RBRACE,
    STATE(174), 1,
      aux_sym_enum_repeat1,
  [5469] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5478] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      anon_sym_RBRACE,
    ACTIONS(505), 1,
      sym_literal,
    STATE(178), 1,
      aux_sym_senum_repeat1,
  [5491] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(507), 1,
      sym_identifier,
    ACTIONS(510), 1,
      anon_sym_RBRACE,
    STATE(174), 1,
      aux_sym_enum_repeat1,
  [5504] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(512), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5513] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(514), 3,
      anon_sym_COMMA,
      anon_sym_GT,
      sym_identifier,
  [5522] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 1,
      sym_identifier,
    ACTIONS(516), 1,
      anon_sym_RBRACE,
    STATE(171), 1,
      aux_sym_enum_repeat1,
  [5535] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 1,
      sym_literal,
    ACTIONS(518), 1,
      anon_sym_RBRACE,
    STATE(169), 1,
      aux_sym_senum_repeat1,
  [5548] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(520), 1,
      anon_sym_LBRACE,
    ACTIONS(522), 1,
      anon_sym_xsd_all,
  [5558] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(510), 2,
      anon_sym_RBRACE,
      sym_identifier,
  [5566] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(524), 1,
      anon_sym_LBRACE,
    ACTIONS(526), 1,
      anon_sym_xsd_all,
  [5576] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(528), 1,
      anon_sym_LBRACE,
    ACTIONS(530), 1,
      anon_sym_extends,
  [5586] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(532), 2,
      anon_sym_RBRACE,
      sym_identifier,
  [5594] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(490), 2,
      anon_sym_RBRACE,
      sym_literal,
  [5602] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(534), 1,
      anon_sym_LBRACE,
  [5609] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(536), 1,
      anon_sym_COLON,
  [5616] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(538), 1,
      anon_sym_COMMA,
  [5623] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(540), 1,
      anon_sym_GT,
  [5630] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(542), 1,
      anon_sym_GT,
  [5637] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(544), 1,
      anon_sym_GT,
  [5644] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(546), 1,
      anon_sym_COMMA,
  [5651] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(548), 1,
      sym_identifier,
  [5658] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(550), 1,
      anon_sym_LBRACE,
  [5665] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(552), 1,
      anon_sym_LBRACE,
  [5672] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(554), 1,
      sym_int_constant,
  [5679] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(556), 1,
      sym_identifier,
  [5686] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(558), 1,
      sym_identifier,
  [5693] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(560), 1,
      anon_sym_EQ,
  [5700] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(562), 1,
      anon_sym_LT,
  [5707] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(564), 1,
      anon_sym_LT,
  [5714] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(566), 1,
      sym_identifier,
  [5721] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(568), 1,
      sym_identifier,
  [5728] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(570), 1,
      anon_sym_LPAREN,
  [5735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(572), 1,
      sym_identifier,
  [5742] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(574), 1,
      sym_identifier,
  [5749] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(576), 1,
      anon_sym_LBRACE,
  [5756] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(578), 1,
      sym_identifier,
  [5763] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(580), 1,
      anon_sym_LBRACE,
  [5770] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(582), 1,
      sym_identifier,
  [5777] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(584), 1,
      sym_literal,
  [5784] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(586), 1,
      anon_sym_GT,
  [5791] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(588), 1,
      sym_identifier,
  [5798] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(590), 1,
      anon_sym_LPAREN,
  [5805] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(592), 1,
      anon_sym_LT,
  [5812] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(594), 1,
      anon_sym_GT,
  [5819] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(596), 1,
      anon_sym_LPAREN,
  [5826] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(598), 1,
      anon_sym_LBRACE,
  [5833] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(600), 1,
      anon_sym_COLON,
  [5840] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(602), 1,
      sym_identifier,
  [5847] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(604), 1,
      sym_identifier,
  [5854] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(606), 1,
      sym_identifier,
  [5861] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(608), 1,
      ts_builtin_sym_end,
  [5868] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(610), 1,
      sym_identifier,
  [5875] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(612), 1,
      sym_identifier,
  [5882] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(614), 1,
      sym_identifier,
  [5889] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(616), 1,
      sym_identifier,
  [5896] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(618), 1,
      sym_identifier,
  [5903] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(620), 1,
      anon_sym_LBRACE,
  [5910] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(622), 1,
      sym_literal,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 39,
  [SMALL_STATE(4)] = 100,
  [SMALL_STATE(5)] = 160,
  [SMALL_STATE(6)] = 220,
  [SMALL_STATE(7)] = 280,
  [SMALL_STATE(8)] = 340,
  [SMALL_STATE(9)] = 400,
  [SMALL_STATE(10)] = 460,
  [SMALL_STATE(11)] = 520,
  [SMALL_STATE(12)] = 580,
  [SMALL_STATE(13)] = 640,
  [SMALL_STATE(14)] = 700,
  [SMALL_STATE(15)] = 760,
  [SMALL_STATE(16)] = 820,
  [SMALL_STATE(17)] = 880,
  [SMALL_STATE(18)] = 940,
  [SMALL_STATE(19)] = 1000,
  [SMALL_STATE(20)] = 1060,
  [SMALL_STATE(21)] = 1120,
  [SMALL_STATE(22)] = 1180,
  [SMALL_STATE(23)] = 1229,
  [SMALL_STATE(24)] = 1278,
  [SMALL_STATE(25)] = 1327,
  [SMALL_STATE(26)] = 1390,
  [SMALL_STATE(27)] = 1446,
  [SMALL_STATE(28)] = 1492,
  [SMALL_STATE(29)] = 1538,
  [SMALL_STATE(30)] = 1594,
  [SMALL_STATE(31)] = 1640,
  [SMALL_STATE(32)] = 1696,
  [SMALL_STATE(33)] = 1752,
  [SMALL_STATE(34)] = 1808,
  [SMALL_STATE(35)] = 1851,
  [SMALL_STATE(36)] = 1894,
  [SMALL_STATE(37)] = 1937,
  [SMALL_STATE(38)] = 1980,
  [SMALL_STATE(39)] = 2023,
  [SMALL_STATE(40)] = 2055,
  [SMALL_STATE(41)] = 2087,
  [SMALL_STATE(42)] = 2127,
  [SMALL_STATE(43)] = 2167,
  [SMALL_STATE(44)] = 2207,
  [SMALL_STATE(45)] = 2239,
  [SMALL_STATE(46)] = 2271,
  [SMALL_STATE(47)] = 2311,
  [SMALL_STATE(48)] = 2343,
  [SMALL_STATE(49)] = 2383,
  [SMALL_STATE(50)] = 2423,
  [SMALL_STATE(51)] = 2470,
  [SMALL_STATE(52)] = 2508,
  [SMALL_STATE(53)] = 2542,
  [SMALL_STATE(54)] = 2588,
  [SMALL_STATE(55)] = 2626,
  [SMALL_STATE(56)] = 2660,
  [SMALL_STATE(57)] = 2694,
  [SMALL_STATE(58)] = 2728,
  [SMALL_STATE(59)] = 2758,
  [SMALL_STATE(60)] = 2796,
  [SMALL_STATE(61)] = 2830,
  [SMALL_STATE(62)] = 2864,
  [SMALL_STATE(63)] = 2898,
  [SMALL_STATE(64)] = 2927,
  [SMALL_STATE(65)] = 2956,
  [SMALL_STATE(66)] = 2996,
  [SMALL_STATE(67)] = 3036,
  [SMALL_STATE(68)] = 3076,
  [SMALL_STATE(69)] = 3116,
  [SMALL_STATE(70)] = 3148,
  [SMALL_STATE(71)] = 3188,
  [SMALL_STATE(72)] = 3228,
  [SMALL_STATE(73)] = 3260,
  [SMALL_STATE(74)] = 3300,
  [SMALL_STATE(75)] = 3332,
  [SMALL_STATE(76)] = 3372,
  [SMALL_STATE(77)] = 3412,
  [SMALL_STATE(78)] = 3452,
  [SMALL_STATE(79)] = 3479,
  [SMALL_STATE(80)] = 3506,
  [SMALL_STATE(81)] = 3533,
  [SMALL_STATE(82)] = 3560,
  [SMALL_STATE(83)] = 3587,
  [SMALL_STATE(84)] = 3614,
  [SMALL_STATE(85)] = 3641,
  [SMALL_STATE(86)] = 3678,
  [SMALL_STATE(87)] = 3723,
  [SMALL_STATE(88)] = 3768,
  [SMALL_STATE(89)] = 3813,
  [SMALL_STATE(90)] = 3840,
  [SMALL_STATE(91)] = 3867,
  [SMALL_STATE(92)] = 3894,
  [SMALL_STATE(93)] = 3919,
  [SMALL_STATE(94)] = 3944,
  [SMALL_STATE(95)] = 3969,
  [SMALL_STATE(96)] = 4002,
  [SMALL_STATE(97)] = 4027,
  [SMALL_STATE(98)] = 4049,
  [SMALL_STATE(99)] = 4069,
  [SMALL_STATE(100)] = 4087,
  [SMALL_STATE(101)] = 4105,
  [SMALL_STATE(102)] = 4127,
  [SMALL_STATE(103)] = 4145,
  [SMALL_STATE(104)] = 4163,
  [SMALL_STATE(105)] = 4181,
  [SMALL_STATE(106)] = 4199,
  [SMALL_STATE(107)] = 4217,
  [SMALL_STATE(108)] = 4235,
  [SMALL_STATE(109)] = 4253,
  [SMALL_STATE(110)] = 4284,
  [SMALL_STATE(111)] = 4315,
  [SMALL_STATE(112)] = 4346,
  [SMALL_STATE(113)] = 4377,
  [SMALL_STATE(114)] = 4408,
  [SMALL_STATE(115)] = 4439,
  [SMALL_STATE(116)] = 4470,
  [SMALL_STATE(117)] = 4501,
  [SMALL_STATE(118)] = 4532,
  [SMALL_STATE(119)] = 4563,
  [SMALL_STATE(120)] = 4594,
  [SMALL_STATE(121)] = 4625,
  [SMALL_STATE(122)] = 4656,
  [SMALL_STATE(123)] = 4687,
  [SMALL_STATE(124)] = 4705,
  [SMALL_STATE(125)] = 4727,
  [SMALL_STATE(126)] = 4745,
  [SMALL_STATE(127)] = 4763,
  [SMALL_STATE(128)] = 4781,
  [SMALL_STATE(129)] = 4803,
  [SMALL_STATE(130)] = 4821,
  [SMALL_STATE(131)] = 4836,
  [SMALL_STATE(132)] = 4851,
  [SMALL_STATE(133)] = 4866,
  [SMALL_STATE(134)] = 4881,
  [SMALL_STATE(135)] = 4896,
  [SMALL_STATE(136)] = 4921,
  [SMALL_STATE(137)] = 4936,
  [SMALL_STATE(138)] = 4951,
  [SMALL_STATE(139)] = 4966,
  [SMALL_STATE(140)] = 4991,
  [SMALL_STATE(141)] = 5006,
  [SMALL_STATE(142)] = 5021,
  [SMALL_STATE(143)] = 5036,
  [SMALL_STATE(144)] = 5051,
  [SMALL_STATE(145)] = 5066,
  [SMALL_STATE(146)] = 5081,
  [SMALL_STATE(147)] = 5096,
  [SMALL_STATE(148)] = 5121,
  [SMALL_STATE(149)] = 5136,
  [SMALL_STATE(150)] = 5161,
  [SMALL_STATE(151)] = 5176,
  [SMALL_STATE(152)] = 5191,
  [SMALL_STATE(153)] = 5206,
  [SMALL_STATE(154)] = 5221,
  [SMALL_STATE(155)] = 5246,
  [SMALL_STATE(156)] = 5262,
  [SMALL_STATE(157)] = 5277,
  [SMALL_STATE(158)] = 5292,
  [SMALL_STATE(159)] = 5310,
  [SMALL_STATE(160)] = 5330,
  [SMALL_STATE(161)] = 5345,
  [SMALL_STATE(162)] = 5360,
  [SMALL_STATE(163)] = 5370,
  [SMALL_STATE(164)] = 5384,
  [SMALL_STATE(165)] = 5398,
  [SMALL_STATE(166)] = 5407,
  [SMALL_STATE(167)] = 5416,
  [SMALL_STATE(168)] = 5425,
  [SMALL_STATE(169)] = 5434,
  [SMALL_STATE(170)] = 5447,
  [SMALL_STATE(171)] = 5456,
  [SMALL_STATE(172)] = 5469,
  [SMALL_STATE(173)] = 5478,
  [SMALL_STATE(174)] = 5491,
  [SMALL_STATE(175)] = 5504,
  [SMALL_STATE(176)] = 5513,
  [SMALL_STATE(177)] = 5522,
  [SMALL_STATE(178)] = 5535,
  [SMALL_STATE(179)] = 5548,
  [SMALL_STATE(180)] = 5558,
  [SMALL_STATE(181)] = 5566,
  [SMALL_STATE(182)] = 5576,
  [SMALL_STATE(183)] = 5586,
  [SMALL_STATE(184)] = 5594,
  [SMALL_STATE(185)] = 5602,
  [SMALL_STATE(186)] = 5609,
  [SMALL_STATE(187)] = 5616,
  [SMALL_STATE(188)] = 5623,
  [SMALL_STATE(189)] = 5630,
  [SMALL_STATE(190)] = 5637,
  [SMALL_STATE(191)] = 5644,
  [SMALL_STATE(192)] = 5651,
  [SMALL_STATE(193)] = 5658,
  [SMALL_STATE(194)] = 5665,
  [SMALL_STATE(195)] = 5672,
  [SMALL_STATE(196)] = 5679,
  [SMALL_STATE(197)] = 5686,
  [SMALL_STATE(198)] = 5693,
  [SMALL_STATE(199)] = 5700,
  [SMALL_STATE(200)] = 5707,
  [SMALL_STATE(201)] = 5714,
  [SMALL_STATE(202)] = 5721,
  [SMALL_STATE(203)] = 5728,
  [SMALL_STATE(204)] = 5735,
  [SMALL_STATE(205)] = 5742,
  [SMALL_STATE(206)] = 5749,
  [SMALL_STATE(207)] = 5756,
  [SMALL_STATE(208)] = 5763,
  [SMALL_STATE(209)] = 5770,
  [SMALL_STATE(210)] = 5777,
  [SMALL_STATE(211)] = 5784,
  [SMALL_STATE(212)] = 5791,
  [SMALL_STATE(213)] = 5798,
  [SMALL_STATE(214)] = 5805,
  [SMALL_STATE(215)] = 5812,
  [SMALL_STATE(216)] = 5819,
  [SMALL_STATE(217)] = 5826,
  [SMALL_STATE(218)] = 5833,
  [SMALL_STATE(219)] = 5840,
  [SMALL_STATE(220)] = 5847,
  [SMALL_STATE(221)] = 5854,
  [SMALL_STATE(222)] = 5861,
  [SMALL_STATE(223)] = 5868,
  [SMALL_STATE(224)] = 5875,
  [SMALL_STATE(225)] = 5882,
  [SMALL_STATE(226)] = 5889,
  [SMALL_STATE(227)] = 5896,
  [SMALL_STATE(228)] = 5903,
  [SMALL_STATE(229)] = 5910,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_document, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(220),
  [33] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_repeat1, 2), SHIFT_REPEAT(167),
  [36] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_struct_repeat1, 2),
  [38] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_repeat1, 2), SHIFT_REPEAT(98),
  [41] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_repeat1, 2), SHIFT_REPEAT(175),
  [44] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_repeat1, 2), SHIFT_REPEAT(163),
  [47] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_repeat1, 2), SHIFT_REPEAT(164),
  [50] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_struct_repeat1, 2), SHIFT_REPEAT(214),
  [53] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_struct_repeat1, 2), SHIFT_REPEAT(186),
  [56] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [58] = {.entry = {.count = 1, .reusable = false}}, SHIFT(98),
  [60] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [62] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [64] = {.entry = {.count = 1, .reusable = false}}, SHIFT(163),
  [66] = {.entry = {.count = 1, .reusable = false}}, SHIFT(164),
  [68] = {.entry = {.count = 1, .reusable = false}}, SHIFT(214),
  [70] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [72] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [74] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [76] = {.entry = {.count = 1, .reusable = true}}, SHIFT(84),
  [78] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [80] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [82] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [84] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [86] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [88] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [90] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [92] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [94] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [96] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [98] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [100] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 4),
  [102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 4),
  [106] = {.entry = {.count = 1, .reusable = false}}, SHIFT(34),
  [108] = {.entry = {.count = 1, .reusable = false}}, SHIFT(42),
  [110] = {.entry = {.count = 1, .reusable = false}}, SHIFT(217),
  [112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [114] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 3),
  [116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 3),
  [120] = {.entry = {.count = 1, .reusable = false}}, SHIFT(36),
  [122] = {.entry = {.count = 1, .reusable = false}}, SHIFT(49),
  [124] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 2),
  [126] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 2),
  [130] = {.entry = {.count = 1, .reusable = false}}, SHIFT(37),
  [132] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_document, 1),
  [136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [138] = {.entry = {.count = 1, .reusable = false}}, SHIFT(53),
  [140] = {.entry = {.count = 1, .reusable = false}}, SHIFT(201),
  [142] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 5),
  [144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 5),
  [146] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [148] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [150] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [152] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 6),
  [154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 6),
  [156] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [158] = {.entry = {.count = 1, .reusable = false}}, SHIFT(43),
  [160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [162] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_service_repeat1, 2), SHIFT_REPEAT(167),
  [165] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_service_repeat1, 2),
  [167] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_service_repeat1, 2), SHIFT_REPEAT(53),
  [170] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_service_repeat1, 2), SHIFT_REPEAT(201),
  [173] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_service_repeat1, 2), SHIFT_REPEAT(175),
  [176] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_service_repeat1, 2), SHIFT_REPEAT(163),
  [179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_service_repeat1, 2), SHIFT_REPEAT(164),
  [182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_service_repeat1, 2), SHIFT_REPEAT(214),
  [185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [187] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 7),
  [189] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 7),
  [191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(46),
  [193] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_list, 2),
  [195] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_list, 2),
  [197] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_list, 3),
  [199] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_list, 3),
  [201] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_value, 1),
  [203] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_value, 1),
  [205] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_map, 3),
  [207] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_map, 3),
  [209] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 8),
  [211] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 8),
  [213] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_map, 2),
  [215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_map, 2),
  [217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function, 4),
  [219] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 4),
  [221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [223] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 9),
  [225] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 9),
  [227] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function, 6),
  [229] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 6),
  [231] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_separator, 1),
  [233] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_separator, 1),
  [235] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function, 5),
  [237] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 5),
  [239] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_xsd_attrs, 4),
  [241] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xsd_attrs, 4),
  [243] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_xsd_attrs, 3),
  [245] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_xsd_attrs, 3),
  [247] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function, 7),
  [249] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 7),
  [251] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throws, 3),
  [253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throws, 3),
  [255] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [263] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2),
  [265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2), SHIFT_REPEAT(77),
  [268] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2), SHIFT_REPEAT(85),
  [271] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2), SHIFT_REPEAT(207),
  [274] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2), SHIFT_REPEAT(227),
  [277] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2), SHIFT_REPEAT(226),
  [280] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2), SHIFT_REPEAT(225),
  [283] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2), SHIFT_REPEAT(224),
  [286] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat2, 2), SHIFT_REPEAT(223),
  [289] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_document, 2),
  [291] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field, 10),
  [293] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field, 10),
  [295] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_throws, 4),
  [297] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_throws, 4),
  [299] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2),
  [301] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2), SHIFT_REPEAT(210),
  [304] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2), SHIFT_REPEAT(229),
  [307] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_document_repeat1, 2), SHIFT_REPEAT(2),
  [310] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function, 8),
  [312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 8),
  [314] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_id, 2),
  [316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_field_req, 1),
  [318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const, 5),
  [320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace, 3),
  [324] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_header, 1),
  [326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include, 2),
  [328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cpp_include, 2),
  [330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [334] = {.entry = {.count = 1, .reusable = false}}, SHIFT(127),
  [336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [340] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_map_repeat1, 2), SHIFT_REPEAT(105),
  [343] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_map_repeat1, 2), SHIFT_REPEAT(115),
  [346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_map_repeat1, 2),
  [348] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_const_map_repeat1, 2), SHIFT_REPEAT(105),
  [351] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_map_repeat1, 2), SHIFT_REPEAT(121),
  [354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [360] = {.entry = {.count = 1, .reusable = false}}, SHIFT(105),
  [362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_list_repeat1, 2), SHIFT_REPEAT(127),
  [369] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_list_repeat1, 2), SHIFT_REPEAT(116),
  [372] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_const_list_repeat1, 2), SHIFT_REPEAT(127),
  [375] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_list_repeat1, 2), SHIFT_REPEAT(117),
  [378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_list_repeat1, 2),
  [380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_list_repeat1, 1),
  [400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [402] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_const_list_repeat1, 1),
  [404] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_map_repeat1, 3),
  [406] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_const_map_repeat1, 3),
  [408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union, 5),
  [410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_typedef, 3),
  [412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 4),
  [414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_definition, 1),
  [416] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union, 4),
  [418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(44),
  [424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception, 4),
  [428] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_service, 4),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_senum, 4),
  [432] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_service, 7),
  [434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 6),
  [436] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_union, 6),
  [438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_service, 5),
  [440] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_service, 6),
  [442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 4),
  [444] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum, 5),
  [446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const, 6),
  [448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_exception, 5),
  [450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_senum, 5),
  [452] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_struct, 5),
  [454] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_const_list_repeat1, 2),
  [456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_map_repeat1, 4),
  [458] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_const_map_repeat1, 4),
  [460] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 1),
  [462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_list_type, 4),
  [466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_type, 4),
  [468] = {.entry = {.count = 1, .reusable = false}}, SHIFT(162),
  [470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [472] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 3),
  [474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_senum_repeat1, 1),
  [476] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_cpp_type, 1),
  [478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_container_type, 1),
  [484] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_type, 4),
  [486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_field_type, 1),
  [488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map_type, 7),
  [490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_senum_repeat1, 2),
  [492] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_senum_repeat1, 2), SHIFT_REPEAT(161),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_type, 5),
  [497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [501] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_map_type, 6),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [507] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2), SHIFT_REPEAT(158),
  [510] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 2),
  [512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_base_type, 1),
  [514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_list_type, 5),
  [516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [532] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_repeat1, 4),
  [534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_definition_type, 1),
  [558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [566] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function_type, 1),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [604] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_namespace_scope, 1),
  [606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [608] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef _WIN32
#define extern __declspec(dllexport)
#endif

extern const TSLanguage *tree_sitter_thrift(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .keyword_lex_fn = ts_lex_keywords,
    .keyword_capture_token = sym_identifier,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
